import typing

import java.lang

class Manifest(java.lang.Object):
    def __init__(self) -> None: ...

    class permission_group(java.lang.Object):
        ACTIVITY_RECOGNITION: typing.ClassVar[str] = ...
        CALENDAR: typing.ClassVar[str] = ...
        CALL_LOG: typing.ClassVar[str] = ...
        CAMERA: typing.ClassVar[str] = ...
        CONTACTS: typing.ClassVar[str] = ...
        LOCATION: typing.ClassVar[str] = ...
        MICROPHONE: typing.ClassVar[str] = ...
        NEARBY_DEVICES: typing.ClassVar[str] = ...
        NOTIFICATIONS: typing.ClassVar[str] = ...
        PHONE: typing.ClassVar[str] = ...
        READ_MEDIA_AURAL: typing.ClassVar[str] = ...
        READ_MEDIA_VISUAL: typing.ClassVar[str] = ...
        SENSORS: typing.ClassVar[str] = ...
        SMS: typing.ClassVar[str] = ...
        STORAGE: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...

    class permission(java.lang.Object):
        ACCEPT_HANDOVER: typing.ClassVar[str] = ...
        ACCESS_BACKGROUND_LOCATION: typing.ClassVar[str] = ...
        ACCESS_BLOBS_ACROSS_USERS: typing.ClassVar[str] = ...
        ACCESS_CHECKIN_PROPERTIES: typing.ClassVar[str] = ...
        ACCESS_COARSE_LOCATION: typing.ClassVar[str] = ...
        ACCESS_FINE_LOCATION: typing.ClassVar[str] = ...
        ACCESS_HIDDEN_PROFILES: typing.ClassVar[str] = ...
        ACCESS_LOCATION_EXTRA_COMMANDS: typing.ClassVar[str] = ...
        ACCESS_MEDIA_LOCATION: typing.ClassVar[str] = ...
        ACCESS_NETWORK_STATE: typing.ClassVar[str] = ...
        ACCESS_NOTIFICATION_POLICY: typing.ClassVar[str] = ...
        ACCESS_WIFI_STATE: typing.ClassVar[str] = ...
        ACCOUNT_MANAGER: typing.ClassVar[str] = ...
        ACTIVITY_RECOGNITION: typing.ClassVar[str] = ...
        ADD_VOICEMAIL: typing.ClassVar[str] = ...
        ANSWER_PHONE_CALLS: typing.ClassVar[str] = ...
        APPLY_PICTURE_PROFILE: typing.ClassVar[str] = ...
        BATTERY_STATS: typing.ClassVar[str] = ...
        BIND_ACCESSIBILITY_SERVICE: typing.ClassVar[str] = ...
        BIND_APPWIDGET: typing.ClassVar[str] = ...
        BIND_APP_FUNCTION_SERVICE: typing.ClassVar[str] = ...
        BIND_AUTOFILL_SERVICE: typing.ClassVar[str] = ...
        BIND_CALL_REDIRECTION_SERVICE: typing.ClassVar[str] = ...
        BIND_CARRIER_MESSAGING_CLIENT_SERVICE: typing.ClassVar[str] = ...
        BIND_CARRIER_MESSAGING_SERVICE: typing.ClassVar[str] = ...
        BIND_CARRIER_SERVICES: typing.ClassVar[str] = ...
        BIND_CHOOSER_TARGET_SERVICE: typing.ClassVar[str] = ...
        BIND_COMPANION_DEVICE_SERVICE: typing.ClassVar[str] = ...
        BIND_CONDITION_PROVIDER_SERVICE: typing.ClassVar[str] = ...
        BIND_CONTROLS: typing.ClassVar[str] = ...
        BIND_CREDENTIAL_PROVIDER_SERVICE: typing.ClassVar[str] = ...
        BIND_DEVICE_ADMIN: typing.ClassVar[str] = ...
        BIND_DREAM_SERVICE: typing.ClassVar[str] = ...
        BIND_INCALL_SERVICE: typing.ClassVar[str] = ...
        BIND_INPUT_METHOD: typing.ClassVar[str] = ...
        BIND_MIDI_DEVICE_SERVICE: typing.ClassVar[str] = ...
        BIND_NFC_SERVICE: typing.ClassVar[str] = ...
        BIND_NOTIFICATION_LISTENER_SERVICE: typing.ClassVar[str] = ...
        BIND_PRINT_SERVICE: typing.ClassVar[str] = ...
        BIND_QUICK_ACCESS_WALLET_SERVICE: typing.ClassVar[str] = ...
        BIND_QUICK_SETTINGS_TILE: typing.ClassVar[str] = ...
        BIND_REMOTEVIEWS: typing.ClassVar[str] = ...
        BIND_SCREENING_SERVICE: typing.ClassVar[str] = ...
        BIND_TELECOM_CONNECTION_SERVICE: typing.ClassVar[str] = ...
        BIND_TEXT_SERVICE: typing.ClassVar[str] = ...
        BIND_TV_AD_SERVICE: typing.ClassVar[str] = ...
        BIND_TV_INPUT: typing.ClassVar[str] = ...
        BIND_TV_INTERACTIVE_APP: typing.ClassVar[str] = ...
        BIND_VISUAL_VOICEMAIL_SERVICE: typing.ClassVar[str] = ...
        BIND_VOICE_INTERACTION: typing.ClassVar[str] = ...
        BIND_VPN_SERVICE: typing.ClassVar[str] = ...
        BIND_VR_LISTENER_SERVICE: typing.ClassVar[str] = ...
        BIND_WALLPAPER: typing.ClassVar[str] = ...
        BLUETOOTH: typing.ClassVar[str] = ...
        BLUETOOTH_ADMIN: typing.ClassVar[str] = ...
        BLUETOOTH_ADVERTISE: typing.ClassVar[str] = ...
        BLUETOOTH_CONNECT: typing.ClassVar[str] = ...
        BLUETOOTH_PRIVILEGED: typing.ClassVar[str] = ...
        BLUETOOTH_SCAN: typing.ClassVar[str] = ...
        BODY_SENSORS: typing.ClassVar[str] = ...
        BODY_SENSORS_BACKGROUND: typing.ClassVar[str] = ...
        BROADCAST_PACKAGE_REMOVED: typing.ClassVar[str] = ...
        BROADCAST_SMS: typing.ClassVar[str] = ...
        BROADCAST_STICKY: typing.ClassVar[str] = ...
        BROADCAST_WAP_PUSH: typing.ClassVar[str] = ...
        CALL_COMPANION_APP: typing.ClassVar[str] = ...
        CALL_PHONE: typing.ClassVar[str] = ...
        CALL_PRIVILEGED: typing.ClassVar[str] = ...
        CAMERA: typing.ClassVar[str] = ...
        CAPTURE_AUDIO_OUTPUT: typing.ClassVar[str] = ...
        CHANGE_COMPONENT_ENABLED_STATE: typing.ClassVar[str] = ...
        CHANGE_CONFIGURATION: typing.ClassVar[str] = ...
        CHANGE_NETWORK_STATE: typing.ClassVar[str] = ...
        CHANGE_WIFI_MULTICAST_STATE: typing.ClassVar[str] = ...
        CHANGE_WIFI_STATE: typing.ClassVar[str] = ...
        CLEAR_APP_CACHE: typing.ClassVar[str] = ...
        CONFIGURE_WIFI_DISPLAY: typing.ClassVar[str] = ...
        CONTROL_LOCATION_UPDATES: typing.ClassVar[str] = ...
        CREDENTIAL_MANAGER_QUERY_CANDIDATE_CREDENTIALS: typing.ClassVar[str] = ...
        CREDENTIAL_MANAGER_SET_ALLOWED_PROVIDERS: typing.ClassVar[str] = ...
        CREDENTIAL_MANAGER_SET_ORIGIN: typing.ClassVar[str] = ...
        DELETE_CACHE_FILES: typing.ClassVar[str] = ...
        DELETE_PACKAGES: typing.ClassVar[str] = ...
        DELIVER_COMPANION_MESSAGES: typing.ClassVar[str] = ...
        DETECT_SCREEN_CAPTURE: typing.ClassVar[str] = ...
        DETECT_SCREEN_RECORDING: typing.ClassVar[str] = ...
        DIAGNOSTIC: typing.ClassVar[str] = ...
        DISABLE_KEYGUARD: typing.ClassVar[str] = ...
        DUMP: typing.ClassVar[str] = ...
        ENFORCE_UPDATE_OWNERSHIP: typing.ClassVar[str] = ...
        EXECUTE_APP_ACTION: typing.ClassVar[str] = ...
        EXECUTE_APP_FUNCTIONS: typing.ClassVar[str] = ...
        EXPAND_STATUS_BAR: typing.ClassVar[str] = ...
        FACTORY_TEST: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_CAMERA: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_CONNECTED_DEVICE: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_DATA_SYNC: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_HEALTH: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_LOCATION: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_MEDIA_PLAYBACK: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_MEDIA_PROCESSING: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_MEDIA_PROJECTION: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_MICROPHONE: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_PHONE_CALL: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_REMOTE_MESSAGING: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_SPECIAL_USE: typing.ClassVar[str] = ...
        FOREGROUND_SERVICE_SYSTEM_EXEMPTED: typing.ClassVar[str] = ...
        GET_ACCOUNTS: typing.ClassVar[str] = ...
        GET_ACCOUNTS_PRIVILEGED: typing.ClassVar[str] = ...
        GET_PACKAGE_SIZE: typing.ClassVar[str] = ...
        GET_TASKS: typing.ClassVar[str] = ...
        GLOBAL_SEARCH: typing.ClassVar[str] = ...
        HIDE_OVERLAY_WINDOWS: typing.ClassVar[str] = ...
        HIGH_SAMPLING_RATE_SENSORS: typing.ClassVar[str] = ...
        INSTALL_LOCATION_PROVIDER: typing.ClassVar[str] = ...
        INSTALL_PACKAGES: typing.ClassVar[str] = ...
        INSTALL_SHORTCUT: typing.ClassVar[str] = ...
        INSTANT_APP_FOREGROUND_SERVICE: typing.ClassVar[str] = ...
        INTERACT_ACROSS_PROFILES: typing.ClassVar[str] = ...
        INTERNET: typing.ClassVar[str] = ...
        KILL_BACKGROUND_PROCESSES: typing.ClassVar[str] = ...
        LAUNCH_CAPTURE_CONTENT_ACTIVITY_FOR_NOTE: typing.ClassVar[str] = ...
        LAUNCH_MULTI_PANE_SETTINGS_DEEP_LINK: typing.ClassVar[str] = ...
        LOADER_USAGE_STATS: typing.ClassVar[str] = ...
        LOCATION_HARDWARE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_LOCK_STATE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_ACCESSIBILITY: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_ACCOUNT_MANAGEMENT: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_ACROSS_USERS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_ACROSS_USERS_FULL: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_ACROSS_USERS_SECURITY_CRITICAL: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_AIRPLANE_MODE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_APPS_CONTROL: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_APP_FUNCTIONS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_APP_RESTRICTIONS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_APP_USER_DATA: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_ASSIST_CONTENT: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_AUDIO_OUTPUT: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_AUTOFILL: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_BACKUP_SERVICE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_BLOCK_UNINSTALL: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_BLUETOOTH: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_BUGREPORT: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_CALLS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_CAMERA: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_CAMERA_TOGGLE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_CERTIFICATES: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_COMMON_CRITERIA_MODE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_CONTENT_PROTECTION: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_DEBUGGING_FEATURES: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_DEFAULT_SMS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_DEVICE_IDENTIFIERS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_DISPLAY: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_FACTORY_RESET: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_FUN: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_INPUT_METHODS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_INSTALL_UNKNOWN_SOURCES: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_KEEP_UNINSTALLED_PACKAGES: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_KEYGUARD: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_LOCALE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_LOCATION: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_LOCK: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_LOCK_CREDENTIALS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_LOCK_TASK: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_MANAGED_SUBSCRIPTIONS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_METERED_DATA: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_MICROPHONE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_MICROPHONE_TOGGLE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_MOBILE_NETWORK: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_MODIFY_USERS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_MTE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_NEARBY_COMMUNICATION: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_NETWORK_LOGGING: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_ORGANIZATION_IDENTITY: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_OVERRIDE_APN: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_PACKAGE_STATE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_PHYSICAL_MEDIA: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_PRINTING: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_PRIVATE_DNS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_PROFILES: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_PROFILE_INTERACTION: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_PROXY: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_QUERY_SYSTEM_UPDATES: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_RESET_PASSWORD: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_RESTRICT_PRIVATE_DNS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_RUNTIME_PERMISSIONS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_RUN_IN_BACKGROUND: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SAFE_BOOT: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SCREEN_CAPTURE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SCREEN_CONTENT: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SECURITY_LOGGING: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SETTINGS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SMS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_STATUS_BAR: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SUPPORT_MESSAGE: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SUSPEND_PERSONAL_APPS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SYSTEM_APPS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SYSTEM_DIALOGS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_SYSTEM_UPDATES: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_THREAD_NETWORK: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_TIME: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_USB_DATA_SIGNALLING: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_USB_FILE_TRANSFER: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_USERS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_VPN: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_WALLPAPER: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_WIFI: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_WINDOWS: typing.ClassVar[str] = ...
        MANAGE_DEVICE_POLICY_WIPE_DATA: typing.ClassVar[str] = ...
        MANAGE_DOCUMENTS: typing.ClassVar[str] = ...
        MANAGE_EXTERNAL_STORAGE: typing.ClassVar[str] = ...
        MANAGE_MEDIA: typing.ClassVar[str] = ...
        MANAGE_ONGOING_CALLS: typing.ClassVar[str] = ...
        MANAGE_OWN_CALLS: typing.ClassVar[str] = ...
        MANAGE_WIFI_INTERFACES: typing.ClassVar[str] = ...
        MANAGE_WIFI_NETWORK_SELECTION: typing.ClassVar[str] = ...
        MASTER_CLEAR: typing.ClassVar[str] = ...
        MEDIA_CONTENT_CONTROL: typing.ClassVar[str] = ...
        MEDIA_ROUTING_CONTROL: typing.ClassVar[str] = ...
        MODIFY_AUDIO_SETTINGS: typing.ClassVar[str] = ...
        MODIFY_PHONE_STATE: typing.ClassVar[str] = ...
        MOUNT_FORMAT_FILESYSTEMS: typing.ClassVar[str] = ...
        MOUNT_UNMOUNT_FILESYSTEMS: typing.ClassVar[str] = ...
        NEARBY_WIFI_DEVICES: typing.ClassVar[str] = ...
        NFC: typing.ClassVar[str] = ...
        NFC_PREFERRED_PAYMENT_INFO: typing.ClassVar[str] = ...
        NFC_TRANSACTION_EVENT: typing.ClassVar[str] = ...
        OVERRIDE_WIFI_CONFIG: typing.ClassVar[str] = ...
        PACKAGE_USAGE_STATS: typing.ClassVar[str] = ...
        PERSISTENT_ACTIVITY: typing.ClassVar[str] = ...
        POST_NOTIFICATIONS: typing.ClassVar[str] = ...
        PROCESS_OUTGOING_CALLS: typing.ClassVar[str] = ...
        PROVIDE_OWN_AUTOFILL_SUGGESTIONS: typing.ClassVar[str] = ...
        PROVIDE_REMOTE_CREDENTIALS: typing.ClassVar[str] = ...
        QUERY_ADVANCED_PROTECTION_MODE: typing.ClassVar[str] = ...
        QUERY_ALL_PACKAGES: typing.ClassVar[str] = ...
        RANGING: typing.ClassVar[str] = ...
        READ_ASSISTANT_APP_SEARCH_DATA: typing.ClassVar[str] = ...
        READ_BASIC_PHONE_STATE: typing.ClassVar[str] = ...
        READ_CALENDAR: typing.ClassVar[str] = ...
        READ_CALL_LOG: typing.ClassVar[str] = ...
        READ_COLOR_ZONES: typing.ClassVar[str] = ...
        READ_CONTACTS: typing.ClassVar[str] = ...
        READ_DROPBOX_DATA: typing.ClassVar[str] = ...
        READ_EXTERNAL_STORAGE: typing.ClassVar[str] = ...
        READ_HOME_APP_SEARCH_DATA: typing.ClassVar[str] = ...
        READ_INPUT_STATE: typing.ClassVar[str] = ...
        READ_LOGS: typing.ClassVar[str] = ...
        READ_MEDIA_AUDIO: typing.ClassVar[str] = ...
        READ_MEDIA_IMAGES: typing.ClassVar[str] = ...
        READ_MEDIA_VIDEO: typing.ClassVar[str] = ...
        READ_MEDIA_VISUAL_USER_SELECTED: typing.ClassVar[str] = ...
        READ_NEARBY_STREAMING_POLICY: typing.ClassVar[str] = ...
        READ_PHONE_NUMBERS: typing.ClassVar[str] = ...
        READ_PHONE_STATE: typing.ClassVar[str] = ...
        READ_PRECISE_PHONE_STATE: typing.ClassVar[str] = ...
        READ_SMS: typing.ClassVar[str] = ...
        READ_SYNC_SETTINGS: typing.ClassVar[str] = ...
        READ_SYNC_STATS: typing.ClassVar[str] = ...
        READ_SYSTEM_PREFERENCES: typing.ClassVar[str] = ...
        READ_VOICEMAIL: typing.ClassVar[str] = ...
        REBOOT: typing.ClassVar[str] = ...
        RECEIVE_BOOT_COMPLETED: typing.ClassVar[str] = ...
        RECEIVE_MMS: typing.ClassVar[str] = ...
        RECEIVE_SMS: typing.ClassVar[str] = ...
        RECEIVE_WAP_PUSH: typing.ClassVar[str] = ...
        RECORD_AUDIO: typing.ClassVar[str] = ...
        REORDER_TASKS: typing.ClassVar[str] = ...
        REQUEST_COMPANION_PROFILE_APP_STREAMING: typing.ClassVar[str] = ...
        REQUEST_COMPANION_PROFILE_AUTOMOTIVE_PROJECTION: typing.ClassVar[str] = ...
        REQUEST_COMPANION_PROFILE_COMPUTER: typing.ClassVar[str] = ...
        REQUEST_COMPANION_PROFILE_GLASSES: typing.ClassVar[str] = ...
        REQUEST_COMPANION_PROFILE_NEARBY_DEVICE_STREAMING: typing.ClassVar[str] = ...
        REQUEST_COMPANION_PROFILE_WATCH: typing.ClassVar[str] = ...
        REQUEST_COMPANION_RUN_IN_BACKGROUND: typing.ClassVar[str] = ...
        REQUEST_COMPANION_SELF_MANAGED: typing.ClassVar[str] = ...
        REQUEST_COMPANION_START_FOREGROUND_SERVICES_FROM_BACKGROUND: typing.ClassVar[str] = ...
        REQUEST_COMPANION_USE_DATA_IN_BACKGROUND: typing.ClassVar[str] = ...
        REQUEST_DELETE_PACKAGES: typing.ClassVar[str] = ...
        REQUEST_IGNORE_BATTERY_OPTIMIZATIONS: typing.ClassVar[str] = ...
        REQUEST_INSTALL_PACKAGES: typing.ClassVar[str] = ...
        REQUEST_OBSERVE_COMPANION_DEVICE_PRESENCE: typing.ClassVar[str] = ...
        REQUEST_OBSERVE_DEVICE_UUID_PRESENCE: typing.ClassVar[str] = ...
        REQUEST_PASSWORD_COMPLEXITY: typing.ClassVar[str] = ...
        RESTART_PACKAGES: typing.ClassVar[str] = ...
        RUN_USER_INITIATED_JOBS: typing.ClassVar[str] = ...
        SCHEDULE_EXACT_ALARM: typing.ClassVar[str] = ...
        SEND_RESPOND_VIA_MESSAGE: typing.ClassVar[str] = ...
        SEND_SMS: typing.ClassVar[str] = ...
        SET_ALARM: typing.ClassVar[str] = ...
        SET_ALWAYS_FINISH: typing.ClassVar[str] = ...
        SET_ANIMATION_SCALE: typing.ClassVar[str] = ...
        SET_BIOMETRIC_DIALOG_ADVANCED: typing.ClassVar[str] = ...
        SET_DEBUG_APP: typing.ClassVar[str] = ...
        SET_PREFERRED_APPLICATIONS: typing.ClassVar[str] = ...
        SET_PROCESS_LIMIT: typing.ClassVar[str] = ...
        SET_TIME: typing.ClassVar[str] = ...
        SET_TIME_ZONE: typing.ClassVar[str] = ...
        SET_WALLPAPER: typing.ClassVar[str] = ...
        SET_WALLPAPER_HINTS: typing.ClassVar[str] = ...
        SIGNAL_PERSISTENT_PROCESSES: typing.ClassVar[str] = ...
        SMS_FINANCIAL_TRANSACTIONS: typing.ClassVar[str] = ...
        START_FOREGROUND_SERVICES_FROM_BACKGROUND: typing.ClassVar[str] = ...
        START_VIEW_APP_FEATURES: typing.ClassVar[str] = ...
        START_VIEW_PERMISSION_USAGE: typing.ClassVar[str] = ...
        STATUS_BAR: typing.ClassVar[str] = ...
        SUBSCRIBE_TO_KEYGUARD_LOCKED_STATE: typing.ClassVar[str] = ...
        SYSTEM_ALERT_WINDOW: typing.ClassVar[str] = ...
        TRANSMIT_IR: typing.ClassVar[str] = ...
        TURN_SCREEN_ON: typing.ClassVar[str] = ...
        TV_IMPLICIT_ENTER_PIP: typing.ClassVar[str] = ...
        UNINSTALL_SHORTCUT: typing.ClassVar[str] = ...
        UPDATE_DEVICE_STATS: typing.ClassVar[str] = ...
        UPDATE_PACKAGES_WITHOUT_USER_ACTION: typing.ClassVar[str] = ...
        USE_BIOMETRIC: typing.ClassVar[str] = ...
        USE_EXACT_ALARM: typing.ClassVar[str] = ...
        USE_FINGERPRINT: typing.ClassVar[str] = ...
        USE_FULL_SCREEN_INTENT: typing.ClassVar[str] = ...
        USE_ICC_AUTH_WITH_DEVICE_IDENTIFIER: typing.ClassVar[str] = ...
        USE_SIP: typing.ClassVar[str] = ...
        UWB_RANGING: typing.ClassVar[str] = ...
        VIBRATE: typing.ClassVar[str] = ...
        WAKE_LOCK: typing.ClassVar[str] = ...
        WRITE_APN_SETTINGS: typing.ClassVar[str] = ...
        WRITE_CALENDAR: typing.ClassVar[str] = ...
        WRITE_CALL_LOG: typing.ClassVar[str] = ...
        WRITE_CONTACTS: typing.ClassVar[str] = ...
        WRITE_EXTERNAL_STORAGE: typing.ClassVar[str] = ...
        WRITE_GSERVICES: typing.ClassVar[str] = ...
        WRITE_SECURE_SETTINGS: typing.ClassVar[str] = ...
        WRITE_SETTINGS: typing.ClassVar[str] = ...
        WRITE_SYNC_SETTINGS: typing.ClassVar[str] = ...
        WRITE_SYSTEM_PREFERENCES: typing.ClassVar[str] = ...
        WRITE_VOICEMAIL: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...

class R(java.lang.Object):
    def __init__(self) -> None: ...

    class xml(java.lang.Object):
        def __init__(self) -> None: ...

    class transition(java.lang.Object):
        explode: typing.ClassVar[int] = ...
        fade: typing.ClassVar[int] = ...
        move: typing.ClassVar[int] = ...
        no_transition: typing.ClassVar[int] = ...
        slide_bottom: typing.ClassVar[int] = ...
        slide_left: typing.ClassVar[int] = ...
        slide_right: typing.ClassVar[int] = ...
        slide_top: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class style(java.lang.Object):
        Animation: typing.ClassVar[int] = ...
        Animation_Activity: typing.ClassVar[int] = ...
        Animation_Dialog: typing.ClassVar[int] = ...
        Animation_InputMethod: typing.ClassVar[int] = ...
        Animation_Toast: typing.ClassVar[int] = ...
        Animation_Translucent: typing.ClassVar[int] = ...
        DeviceDefault_ButtonBar: typing.ClassVar[int] = ...
        DeviceDefault_ButtonBar_AlertDialog: typing.ClassVar[int] = ...
        DeviceDefault_Light_ButtonBar: typing.ClassVar[int] = ...
        DeviceDefault_Light_ButtonBar_AlertDialog: typing.ClassVar[int] = ...
        DeviceDefault_Light_SegmentedButton: typing.ClassVar[int] = ...
        DeviceDefault_SegmentedButton: typing.ClassVar[int] = ...
        Holo_ButtonBar: typing.ClassVar[int] = ...
        Holo_ButtonBar_AlertDialog: typing.ClassVar[int] = ...
        Holo_Light_ButtonBar: typing.ClassVar[int] = ...
        Holo_Light_ButtonBar_AlertDialog: typing.ClassVar[int] = ...
        Holo_Light_SegmentedButton: typing.ClassVar[int] = ...
        Holo_SegmentedButton: typing.ClassVar[int] = ...
        MediaButton: typing.ClassVar[int] = ...
        MediaButton_Ffwd: typing.ClassVar[int] = ...
        MediaButton_Next: typing.ClassVar[int] = ...
        MediaButton_Pause: typing.ClassVar[int] = ...
        MediaButton_Play: typing.ClassVar[int] = ...
        MediaButton_Previous: typing.ClassVar[int] = ...
        MediaButton_Rew: typing.ClassVar[int] = ...
        TextAppearance: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_DialogWindowTitle: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Headline: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Inverse: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Large: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Large_Inverse: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Medium: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Medium_Inverse: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_SearchResult_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_SearchResult_Title: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Small: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Small_Inverse: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionBar_Menu: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionBar_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionBar_Subtitle_Inverse: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionBar_Title: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionBar_Title_Inverse: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionMode_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionMode_Subtitle_Inverse: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionMode_Title: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_ActionMode_Title_Inverse: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_Button: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_DropDownHint: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_DropDownItem: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_EditText: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_IconMenu_Item: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_PopupMenu: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_PopupMenu_Large: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_PopupMenu_Small: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_TabWidget: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_TextView: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_TextView_PopupMenu: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_Widget_TextView_SpinnerItem: typing.ClassVar[int] = ...
        TextAppearance_DeviceDefault_WindowTitle: typing.ClassVar[int] = ...
        TextAppearance_DialogWindowTitle: typing.ClassVar[int] = ...
        TextAppearance_Holo: typing.ClassVar[int] = ...
        TextAppearance_Holo_DialogWindowTitle: typing.ClassVar[int] = ...
        TextAppearance_Holo_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Holo_Large: typing.ClassVar[int] = ...
        TextAppearance_Holo_Large_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Holo_Medium: typing.ClassVar[int] = ...
        TextAppearance_Holo_Medium_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Holo_SearchResult_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_Holo_SearchResult_Title: typing.ClassVar[int] = ...
        TextAppearance_Holo_Small: typing.ClassVar[int] = ...
        TextAppearance_Holo_Small_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionBar_Menu: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionBar_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionBar_Subtitle_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionBar_Title: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionBar_Title_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionMode_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionMode_Subtitle_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionMode_Title: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_ActionMode_Title_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_Button: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_DropDownHint: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_DropDownItem: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_EditText: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_IconMenu_Item: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_PopupMenu: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_PopupMenu_Large: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_PopupMenu_Small: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_TabWidget: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_TextView: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_TextView_PopupMenu: typing.ClassVar[int] = ...
        TextAppearance_Holo_Widget_TextView_SpinnerItem: typing.ClassVar[int] = ...
        TextAppearance_Holo_WindowTitle: typing.ClassVar[int] = ...
        TextAppearance_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Large: typing.ClassVar[int] = ...
        TextAppearance_Large_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material: typing.ClassVar[int] = ...
        TextAppearance_Material_Body1: typing.ClassVar[int] = ...
        TextAppearance_Material_Body2: typing.ClassVar[int] = ...
        TextAppearance_Material_Button: typing.ClassVar[int] = ...
        TextAppearance_Material_Caption: typing.ClassVar[int] = ...
        TextAppearance_Material_DialogWindowTitle: typing.ClassVar[int] = ...
        TextAppearance_Material_Display1: typing.ClassVar[int] = ...
        TextAppearance_Material_Display2: typing.ClassVar[int] = ...
        TextAppearance_Material_Display3: typing.ClassVar[int] = ...
        TextAppearance_Material_Display4: typing.ClassVar[int] = ...
        TextAppearance_Material_Headline: typing.ClassVar[int] = ...
        TextAppearance_Material_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Large: typing.ClassVar[int] = ...
        TextAppearance_Material_Large_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Medium: typing.ClassVar[int] = ...
        TextAppearance_Material_Medium_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Menu: typing.ClassVar[int] = ...
        TextAppearance_Material_Notification: typing.ClassVar[int] = ...
        TextAppearance_Material_Notification_Emphasis: typing.ClassVar[int] = ...
        TextAppearance_Material_Notification_Info: typing.ClassVar[int] = ...
        TextAppearance_Material_Notification_Line2: typing.ClassVar[int] = ...
        TextAppearance_Material_Notification_Time: typing.ClassVar[int] = ...
        TextAppearance_Material_Notification_Title: typing.ClassVar[int] = ...
        TextAppearance_Material_SearchResult_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_Material_SearchResult_Title: typing.ClassVar[int] = ...
        TextAppearance_Material_Small: typing.ClassVar[int] = ...
        TextAppearance_Material_Small_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Subhead: typing.ClassVar[int] = ...
        TextAppearance_Material_Title: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionBar_Menu: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionBar_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionBar_Subtitle_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionBar_Title: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionBar_Title_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionMode_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionMode_Subtitle_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionMode_Title: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_ActionMode_Title_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_Button: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_Button_Borderless_Colored: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_Button_Colored: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_Button_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_DropDownHint: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_DropDownItem: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_EditText: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_IconMenu_Item: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_PopupMenu: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_PopupMenu_Large: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_PopupMenu_Small: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_TabWidget: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_TextView: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_TextView_PopupMenu: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_TextView_SpinnerItem: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_Toolbar_Subtitle: typing.ClassVar[int] = ...
        TextAppearance_Material_Widget_Toolbar_Title: typing.ClassVar[int] = ...
        TextAppearance_Material_WindowTitle: typing.ClassVar[int] = ...
        TextAppearance_Medium: typing.ClassVar[int] = ...
        TextAppearance_Medium_Inverse: typing.ClassVar[int] = ...
        TextAppearance_Small: typing.ClassVar[int] = ...
        TextAppearance_Small_Inverse: typing.ClassVar[int] = ...
        TextAppearance_StatusBar_EventContent: typing.ClassVar[int] = ...
        TextAppearance_StatusBar_EventContent_Title: typing.ClassVar[int] = ...
        TextAppearance_StatusBar_Icon: typing.ClassVar[int] = ...
        TextAppearance_StatusBar_Title: typing.ClassVar[int] = ...
        TextAppearance_SuggestionHighlight: typing.ClassVar[int] = ...
        TextAppearance_Theme: typing.ClassVar[int] = ...
        TextAppearance_Theme_Dialog: typing.ClassVar[int] = ...
        TextAppearance_Widget: typing.ClassVar[int] = ...
        TextAppearance_Widget_Button: typing.ClassVar[int] = ...
        TextAppearance_Widget_DropDownHint: typing.ClassVar[int] = ...
        TextAppearance_Widget_DropDownItem: typing.ClassVar[int] = ...
        TextAppearance_Widget_EditText: typing.ClassVar[int] = ...
        TextAppearance_Widget_IconMenu_Item: typing.ClassVar[int] = ...
        TextAppearance_Widget_PopupMenu_Large: typing.ClassVar[int] = ...
        TextAppearance_Widget_PopupMenu_Small: typing.ClassVar[int] = ...
        TextAppearance_Widget_TabWidget: typing.ClassVar[int] = ...
        TextAppearance_Widget_TextView: typing.ClassVar[int] = ...
        TextAppearance_Widget_TextView_PopupMenu: typing.ClassVar[int] = ...
        TextAppearance_Widget_TextView_SpinnerItem: typing.ClassVar[int] = ...
        TextAppearance_WindowTitle: typing.ClassVar[int] = ...
        Theme: typing.ClassVar[int] = ...
        ThemeOverlay: typing.ClassVar[int] = ...
        ThemeOverlay_DeviceDefault_Accent_DayNight: typing.ClassVar[int] = ...
        ThemeOverlay_Material: typing.ClassVar[int] = ...
        ThemeOverlay_Material_ActionBar: typing.ClassVar[int] = ...
        ThemeOverlay_Material_Dark: typing.ClassVar[int] = ...
        ThemeOverlay_Material_Dark_ActionBar: typing.ClassVar[int] = ...
        ThemeOverlay_Material_Dialog: typing.ClassVar[int] = ...
        ThemeOverlay_Material_Dialog_Alert: typing.ClassVar[int] = ...
        ThemeOverlay_Material_Light: typing.ClassVar[int] = ...
        Theme_Black: typing.ClassVar[int] = ...
        Theme_Black_NoTitleBar: typing.ClassVar[int] = ...
        Theme_Black_NoTitleBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_DeviceDefault: typing.ClassVar[int] = ...
        Theme_DeviceDefault_DayNight: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Dialog: typing.ClassVar[int] = ...
        Theme_DeviceDefault_DialogWhenLarge: typing.ClassVar[int] = ...
        Theme_DeviceDefault_DialogWhenLarge_NoActionBar: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Dialog_Alert: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Dialog_MinWidth: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Dialog_NoActionBar: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Dialog_NoActionBar_MinWidth: typing.ClassVar[int] = ...
        Theme_DeviceDefault_InputMethod: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_DarkActionBar: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_Dialog: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_DialogWhenLarge: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_DialogWhenLarge_NoActionBar: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_Dialog_Alert: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_Dialog_MinWidth: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_Dialog_NoActionBar: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_Dialog_NoActionBar_MinWidth: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_NoActionBar: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_NoActionBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_NoActionBar_Overscan: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_NoActionBar_TranslucentDecor: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Light_Panel: typing.ClassVar[int] = ...
        Theme_DeviceDefault_NoActionBar: typing.ClassVar[int] = ...
        Theme_DeviceDefault_NoActionBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_DeviceDefault_NoActionBar_Overscan: typing.ClassVar[int] = ...
        Theme_DeviceDefault_NoActionBar_TranslucentDecor: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Panel: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Settings: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Wallpaper: typing.ClassVar[int] = ...
        Theme_DeviceDefault_Wallpaper_NoTitleBar: typing.ClassVar[int] = ...
        Theme_Dialog: typing.ClassVar[int] = ...
        Theme_Holo: typing.ClassVar[int] = ...
        Theme_Holo_Dialog: typing.ClassVar[int] = ...
        Theme_Holo_DialogWhenLarge: typing.ClassVar[int] = ...
        Theme_Holo_DialogWhenLarge_NoActionBar: typing.ClassVar[int] = ...
        Theme_Holo_Dialog_MinWidth: typing.ClassVar[int] = ...
        Theme_Holo_Dialog_NoActionBar: typing.ClassVar[int] = ...
        Theme_Holo_Dialog_NoActionBar_MinWidth: typing.ClassVar[int] = ...
        Theme_Holo_InputMethod: typing.ClassVar[int] = ...
        Theme_Holo_Light: typing.ClassVar[int] = ...
        Theme_Holo_Light_DarkActionBar: typing.ClassVar[int] = ...
        Theme_Holo_Light_Dialog: typing.ClassVar[int] = ...
        Theme_Holo_Light_DialogWhenLarge: typing.ClassVar[int] = ...
        Theme_Holo_Light_DialogWhenLarge_NoActionBar: typing.ClassVar[int] = ...
        Theme_Holo_Light_Dialog_MinWidth: typing.ClassVar[int] = ...
        Theme_Holo_Light_Dialog_NoActionBar: typing.ClassVar[int] = ...
        Theme_Holo_Light_Dialog_NoActionBar_MinWidth: typing.ClassVar[int] = ...
        Theme_Holo_Light_NoActionBar: typing.ClassVar[int] = ...
        Theme_Holo_Light_NoActionBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_Holo_Light_NoActionBar_Overscan: typing.ClassVar[int] = ...
        Theme_Holo_Light_NoActionBar_TranslucentDecor: typing.ClassVar[int] = ...
        Theme_Holo_Light_Panel: typing.ClassVar[int] = ...
        Theme_Holo_NoActionBar: typing.ClassVar[int] = ...
        Theme_Holo_NoActionBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_Holo_NoActionBar_Overscan: typing.ClassVar[int] = ...
        Theme_Holo_NoActionBar_TranslucentDecor: typing.ClassVar[int] = ...
        Theme_Holo_Panel: typing.ClassVar[int] = ...
        Theme_Holo_Wallpaper: typing.ClassVar[int] = ...
        Theme_Holo_Wallpaper_NoTitleBar: typing.ClassVar[int] = ...
        Theme_InputMethod: typing.ClassVar[int] = ...
        Theme_Light: typing.ClassVar[int] = ...
        Theme_Light_NoTitleBar: typing.ClassVar[int] = ...
        Theme_Light_NoTitleBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_Light_Panel: typing.ClassVar[int] = ...
        Theme_Light_WallpaperSettings: typing.ClassVar[int] = ...
        Theme_Material: typing.ClassVar[int] = ...
        Theme_Material_Dialog: typing.ClassVar[int] = ...
        Theme_Material_DialogWhenLarge: typing.ClassVar[int] = ...
        Theme_Material_DialogWhenLarge_NoActionBar: typing.ClassVar[int] = ...
        Theme_Material_Dialog_Alert: typing.ClassVar[int] = ...
        Theme_Material_Dialog_MinWidth: typing.ClassVar[int] = ...
        Theme_Material_Dialog_NoActionBar: typing.ClassVar[int] = ...
        Theme_Material_Dialog_NoActionBar_MinWidth: typing.ClassVar[int] = ...
        Theme_Material_Dialog_Presentation: typing.ClassVar[int] = ...
        Theme_Material_InputMethod: typing.ClassVar[int] = ...
        Theme_Material_Light: typing.ClassVar[int] = ...
        Theme_Material_Light_DarkActionBar: typing.ClassVar[int] = ...
        Theme_Material_Light_Dialog: typing.ClassVar[int] = ...
        Theme_Material_Light_DialogWhenLarge: typing.ClassVar[int] = ...
        Theme_Material_Light_DialogWhenLarge_DarkActionBar: typing.ClassVar[int] = ...
        Theme_Material_Light_DialogWhenLarge_NoActionBar: typing.ClassVar[int] = ...
        Theme_Material_Light_Dialog_Alert: typing.ClassVar[int] = ...
        Theme_Material_Light_Dialog_MinWidth: typing.ClassVar[int] = ...
        Theme_Material_Light_Dialog_NoActionBar: typing.ClassVar[int] = ...
        Theme_Material_Light_Dialog_NoActionBar_MinWidth: typing.ClassVar[int] = ...
        Theme_Material_Light_Dialog_Presentation: typing.ClassVar[int] = ...
        Theme_Material_Light_LightStatusBar: typing.ClassVar[int] = ...
        Theme_Material_Light_NoActionBar: typing.ClassVar[int] = ...
        Theme_Material_Light_NoActionBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_Material_Light_NoActionBar_Overscan: typing.ClassVar[int] = ...
        Theme_Material_Light_NoActionBar_TranslucentDecor: typing.ClassVar[int] = ...
        Theme_Material_Light_Panel: typing.ClassVar[int] = ...
        Theme_Material_Light_Voice: typing.ClassVar[int] = ...
        Theme_Material_NoActionBar: typing.ClassVar[int] = ...
        Theme_Material_NoActionBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_Material_NoActionBar_Overscan: typing.ClassVar[int] = ...
        Theme_Material_NoActionBar_TranslucentDecor: typing.ClassVar[int] = ...
        Theme_Material_Panel: typing.ClassVar[int] = ...
        Theme_Material_Settings: typing.ClassVar[int] = ...
        Theme_Material_Voice: typing.ClassVar[int] = ...
        Theme_Material_Wallpaper: typing.ClassVar[int] = ...
        Theme_Material_Wallpaper_NoTitleBar: typing.ClassVar[int] = ...
        Theme_NoDisplay: typing.ClassVar[int] = ...
        Theme_NoTitleBar: typing.ClassVar[int] = ...
        Theme_NoTitleBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_NoTitleBar_OverlayActionModes: typing.ClassVar[int] = ...
        Theme_Panel: typing.ClassVar[int] = ...
        Theme_Translucent: typing.ClassVar[int] = ...
        Theme_Translucent_NoTitleBar: typing.ClassVar[int] = ...
        Theme_Translucent_NoTitleBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_Wallpaper: typing.ClassVar[int] = ...
        Theme_WallpaperSettings: typing.ClassVar[int] = ...
        Theme_Wallpaper_NoTitleBar: typing.ClassVar[int] = ...
        Theme_Wallpaper_NoTitleBar_Fullscreen: typing.ClassVar[int] = ...
        Theme_WithActionBar: typing.ClassVar[int] = ...
        Widget: typing.ClassVar[int] = ...
        Widget_AbsListView: typing.ClassVar[int] = ...
        Widget_ActionBar: typing.ClassVar[int] = ...
        Widget_ActionBar_TabBar: typing.ClassVar[int] = ...
        Widget_ActionBar_TabText: typing.ClassVar[int] = ...
        Widget_ActionBar_TabView: typing.ClassVar[int] = ...
        Widget_ActionButton: typing.ClassVar[int] = ...
        Widget_ActionButton_CloseMode: typing.ClassVar[int] = ...
        Widget_ActionButton_Overflow: typing.ClassVar[int] = ...
        Widget_AutoCompleteTextView: typing.ClassVar[int] = ...
        Widget_Button: typing.ClassVar[int] = ...
        Widget_Button_Inset: typing.ClassVar[int] = ...
        Widget_Button_Small: typing.ClassVar[int] = ...
        Widget_Button_Toggle: typing.ClassVar[int] = ...
        Widget_CalendarView: typing.ClassVar[int] = ...
        Widget_CompoundButton: typing.ClassVar[int] = ...
        Widget_CompoundButton_CheckBox: typing.ClassVar[int] = ...
        Widget_CompoundButton_RadioButton: typing.ClassVar[int] = ...
        Widget_CompoundButton_Star: typing.ClassVar[int] = ...
        Widget_DatePicker: typing.ClassVar[int] = ...
        Widget_DeviceDefault: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionBar_Solid: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionBar_TabBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionBar_TabText: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionBar_TabView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionButton_CloseMode: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionButton_Overflow: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionButton_TextButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ActionMode: typing.ClassVar[int] = ...
        Widget_DeviceDefault_AutoCompleteTextView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Button: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Button_Borderless: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Button_Borderless_Colored: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Button_Borderless_Small: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Button_Colored: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Button_Inset: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Button_Small: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Button_Toggle: typing.ClassVar[int] = ...
        Widget_DeviceDefault_CalendarView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_CheckedTextView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_CompoundButton_CheckBox: typing.ClassVar[int] = ...
        Widget_DeviceDefault_CompoundButton_RadioButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_CompoundButton_Star: typing.ClassVar[int] = ...
        Widget_DeviceDefault_DatePicker: typing.ClassVar[int] = ...
        Widget_DeviceDefault_DropDownItem: typing.ClassVar[int] = ...
        Widget_DeviceDefault_DropDownItem_Spinner: typing.ClassVar[int] = ...
        Widget_DeviceDefault_EditText: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ExpandableListView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_FastScroll: typing.ClassVar[int] = ...
        Widget_DeviceDefault_GridView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_HorizontalScrollView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ImageButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar_Solid: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar_Solid_Inverse: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar_TabBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar_TabBar_Inverse: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar_TabText: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar_TabText_Inverse: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar_TabView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionBar_TabView_Inverse: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionButton_CloseMode: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionButton_Overflow: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionMode: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ActionMode_Inverse: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_AutoCompleteTextView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_Button: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_Button_Borderless_Small: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_Button_Inset: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_Button_Small: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_Button_Toggle: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_CalendarView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_CheckedTextView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_CompoundButton_CheckBox: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_CompoundButton_RadioButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_CompoundButton_Star: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_DropDownItem: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_DropDownItem_Spinner: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_EditText: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ExpandableListView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_FastScroll: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_GridView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_HorizontalScrollView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ImageButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ListPopupWindow: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ListView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ListView_DropDown: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_MediaRouteButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_PopupMenu: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_PopupWindow: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ProgressBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ProgressBar_Horizontal: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ProgressBar_Inverse: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ProgressBar_Large: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ProgressBar_Large_Inverse: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ProgressBar_Small: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ProgressBar_Small_Inverse: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ProgressBar_Small_Title: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_RatingBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_RatingBar_Indicator: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_RatingBar_Small: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_ScrollView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_SeekBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_Spinner: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_StackView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_Tab: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_TabWidget: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_TextView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_TextView_SpinnerItem: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_WebTextView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Light_WebView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ListPopupWindow: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ListView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ListView_DropDown: typing.ClassVar[int] = ...
        Widget_DeviceDefault_MediaRouteButton: typing.ClassVar[int] = ...
        Widget_DeviceDefault_PopupMenu: typing.ClassVar[int] = ...
        Widget_DeviceDefault_PopupWindow: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ProgressBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ProgressBar_Horizontal: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ProgressBar_Large: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ProgressBar_Small: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ProgressBar_Small_Title: typing.ClassVar[int] = ...
        Widget_DeviceDefault_RatingBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_RatingBar_Indicator: typing.ClassVar[int] = ...
        Widget_DeviceDefault_RatingBar_Small: typing.ClassVar[int] = ...
        Widget_DeviceDefault_ScrollView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_SeekBar: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Spinner: typing.ClassVar[int] = ...
        Widget_DeviceDefault_StackView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_Tab: typing.ClassVar[int] = ...
        Widget_DeviceDefault_TabWidget: typing.ClassVar[int] = ...
        Widget_DeviceDefault_TextView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_TextView_SpinnerItem: typing.ClassVar[int] = ...
        Widget_DeviceDefault_WebTextView: typing.ClassVar[int] = ...
        Widget_DeviceDefault_WebView: typing.ClassVar[int] = ...
        Widget_DropDownItem: typing.ClassVar[int] = ...
        Widget_DropDownItem_Spinner: typing.ClassVar[int] = ...
        Widget_EditText: typing.ClassVar[int] = ...
        Widget_ExpandableListView: typing.ClassVar[int] = ...
        Widget_FastScroll: typing.ClassVar[int] = ...
        Widget_FragmentBreadCrumbs: typing.ClassVar[int] = ...
        Widget_Gallery: typing.ClassVar[int] = ...
        Widget_GridView: typing.ClassVar[int] = ...
        Widget_Holo: typing.ClassVar[int] = ...
        Widget_Holo_ActionBar: typing.ClassVar[int] = ...
        Widget_Holo_ActionBar_Solid: typing.ClassVar[int] = ...
        Widget_Holo_ActionBar_TabBar: typing.ClassVar[int] = ...
        Widget_Holo_ActionBar_TabText: typing.ClassVar[int] = ...
        Widget_Holo_ActionBar_TabView: typing.ClassVar[int] = ...
        Widget_Holo_ActionButton: typing.ClassVar[int] = ...
        Widget_Holo_ActionButton_CloseMode: typing.ClassVar[int] = ...
        Widget_Holo_ActionButton_Overflow: typing.ClassVar[int] = ...
        Widget_Holo_ActionButton_TextButton: typing.ClassVar[int] = ...
        Widget_Holo_ActionMode: typing.ClassVar[int] = ...
        Widget_Holo_AutoCompleteTextView: typing.ClassVar[int] = ...
        Widget_Holo_Button: typing.ClassVar[int] = ...
        Widget_Holo_Button_Borderless: typing.ClassVar[int] = ...
        Widget_Holo_Button_Borderless_Small: typing.ClassVar[int] = ...
        Widget_Holo_Button_Inset: typing.ClassVar[int] = ...
        Widget_Holo_Button_Small: typing.ClassVar[int] = ...
        Widget_Holo_Button_Toggle: typing.ClassVar[int] = ...
        Widget_Holo_CalendarView: typing.ClassVar[int] = ...
        Widget_Holo_CheckedTextView: typing.ClassVar[int] = ...
        Widget_Holo_CompoundButton_CheckBox: typing.ClassVar[int] = ...
        Widget_Holo_CompoundButton_RadioButton: typing.ClassVar[int] = ...
        Widget_Holo_CompoundButton_Star: typing.ClassVar[int] = ...
        Widget_Holo_DatePicker: typing.ClassVar[int] = ...
        Widget_Holo_DropDownItem: typing.ClassVar[int] = ...
        Widget_Holo_DropDownItem_Spinner: typing.ClassVar[int] = ...
        Widget_Holo_EditText: typing.ClassVar[int] = ...
        Widget_Holo_ExpandableListView: typing.ClassVar[int] = ...
        Widget_Holo_GridView: typing.ClassVar[int] = ...
        Widget_Holo_HorizontalScrollView: typing.ClassVar[int] = ...
        Widget_Holo_ImageButton: typing.ClassVar[int] = ...
        Widget_Holo_Light: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar_Solid: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar_Solid_Inverse: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar_TabBar: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar_TabBar_Inverse: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar_TabText: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar_TabText_Inverse: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar_TabView: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionBar_TabView_Inverse: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionButton: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionButton_CloseMode: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionButton_Overflow: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionMode: typing.ClassVar[int] = ...
        Widget_Holo_Light_ActionMode_Inverse: typing.ClassVar[int] = ...
        Widget_Holo_Light_AutoCompleteTextView: typing.ClassVar[int] = ...
        Widget_Holo_Light_Button: typing.ClassVar[int] = ...
        Widget_Holo_Light_Button_Borderless_Small: typing.ClassVar[int] = ...
        Widget_Holo_Light_Button_Inset: typing.ClassVar[int] = ...
        Widget_Holo_Light_Button_Small: typing.ClassVar[int] = ...
        Widget_Holo_Light_Button_Toggle: typing.ClassVar[int] = ...
        Widget_Holo_Light_CalendarView: typing.ClassVar[int] = ...
        Widget_Holo_Light_CheckedTextView: typing.ClassVar[int] = ...
        Widget_Holo_Light_CompoundButton_CheckBox: typing.ClassVar[int] = ...
        Widget_Holo_Light_CompoundButton_RadioButton: typing.ClassVar[int] = ...
        Widget_Holo_Light_CompoundButton_Star: typing.ClassVar[int] = ...
        Widget_Holo_Light_DropDownItem: typing.ClassVar[int] = ...
        Widget_Holo_Light_DropDownItem_Spinner: typing.ClassVar[int] = ...
        Widget_Holo_Light_EditText: typing.ClassVar[int] = ...
        Widget_Holo_Light_ExpandableListView: typing.ClassVar[int] = ...
        Widget_Holo_Light_GridView: typing.ClassVar[int] = ...
        Widget_Holo_Light_HorizontalScrollView: typing.ClassVar[int] = ...
        Widget_Holo_Light_ImageButton: typing.ClassVar[int] = ...
        Widget_Holo_Light_ListPopupWindow: typing.ClassVar[int] = ...
        Widget_Holo_Light_ListView: typing.ClassVar[int] = ...
        Widget_Holo_Light_ListView_DropDown: typing.ClassVar[int] = ...
        Widget_Holo_Light_MediaRouteButton: typing.ClassVar[int] = ...
        Widget_Holo_Light_PopupMenu: typing.ClassVar[int] = ...
        Widget_Holo_Light_PopupWindow: typing.ClassVar[int] = ...
        Widget_Holo_Light_ProgressBar: typing.ClassVar[int] = ...
        Widget_Holo_Light_ProgressBar_Horizontal: typing.ClassVar[int] = ...
        Widget_Holo_Light_ProgressBar_Inverse: typing.ClassVar[int] = ...
        Widget_Holo_Light_ProgressBar_Large: typing.ClassVar[int] = ...
        Widget_Holo_Light_ProgressBar_Large_Inverse: typing.ClassVar[int] = ...
        Widget_Holo_Light_ProgressBar_Small: typing.ClassVar[int] = ...
        Widget_Holo_Light_ProgressBar_Small_Inverse: typing.ClassVar[int] = ...
        Widget_Holo_Light_ProgressBar_Small_Title: typing.ClassVar[int] = ...
        Widget_Holo_Light_RatingBar: typing.ClassVar[int] = ...
        Widget_Holo_Light_RatingBar_Indicator: typing.ClassVar[int] = ...
        Widget_Holo_Light_RatingBar_Small: typing.ClassVar[int] = ...
        Widget_Holo_Light_ScrollView: typing.ClassVar[int] = ...
        Widget_Holo_Light_SeekBar: typing.ClassVar[int] = ...
        Widget_Holo_Light_Spinner: typing.ClassVar[int] = ...
        Widget_Holo_Light_Tab: typing.ClassVar[int] = ...
        Widget_Holo_Light_TabWidget: typing.ClassVar[int] = ...
        Widget_Holo_Light_TextView: typing.ClassVar[int] = ...
        Widget_Holo_Light_TextView_SpinnerItem: typing.ClassVar[int] = ...
        Widget_Holo_Light_WebTextView: typing.ClassVar[int] = ...
        Widget_Holo_Light_WebView: typing.ClassVar[int] = ...
        Widget_Holo_ListPopupWindow: typing.ClassVar[int] = ...
        Widget_Holo_ListView: typing.ClassVar[int] = ...
        Widget_Holo_ListView_DropDown: typing.ClassVar[int] = ...
        Widget_Holo_MediaRouteButton: typing.ClassVar[int] = ...
        Widget_Holo_PopupMenu: typing.ClassVar[int] = ...
        Widget_Holo_PopupWindow: typing.ClassVar[int] = ...
        Widget_Holo_ProgressBar: typing.ClassVar[int] = ...
        Widget_Holo_ProgressBar_Horizontal: typing.ClassVar[int] = ...
        Widget_Holo_ProgressBar_Large: typing.ClassVar[int] = ...
        Widget_Holo_ProgressBar_Small: typing.ClassVar[int] = ...
        Widget_Holo_ProgressBar_Small_Title: typing.ClassVar[int] = ...
        Widget_Holo_RatingBar: typing.ClassVar[int] = ...
        Widget_Holo_RatingBar_Indicator: typing.ClassVar[int] = ...
        Widget_Holo_RatingBar_Small: typing.ClassVar[int] = ...
        Widget_Holo_ScrollView: typing.ClassVar[int] = ...
        Widget_Holo_SeekBar: typing.ClassVar[int] = ...
        Widget_Holo_Spinner: typing.ClassVar[int] = ...
        Widget_Holo_Tab: typing.ClassVar[int] = ...
        Widget_Holo_TabWidget: typing.ClassVar[int] = ...
        Widget_Holo_TextView: typing.ClassVar[int] = ...
        Widget_Holo_TextView_SpinnerItem: typing.ClassVar[int] = ...
        Widget_Holo_WebTextView: typing.ClassVar[int] = ...
        Widget_Holo_WebView: typing.ClassVar[int] = ...
        Widget_ImageButton: typing.ClassVar[int] = ...
        Widget_ImageWell: typing.ClassVar[int] = ...
        Widget_KeyboardView: typing.ClassVar[int] = ...
        Widget_ListPopupWindow: typing.ClassVar[int] = ...
        Widget_ListView: typing.ClassVar[int] = ...
        Widget_ListView_DropDown: typing.ClassVar[int] = ...
        Widget_ListView_Menu: typing.ClassVar[int] = ...
        Widget_ListView_White: typing.ClassVar[int] = ...
        Widget_Material: typing.ClassVar[int] = ...
        Widget_Material_ActionBar: typing.ClassVar[int] = ...
        Widget_Material_ActionBar_Solid: typing.ClassVar[int] = ...
        Widget_Material_ActionBar_TabBar: typing.ClassVar[int] = ...
        Widget_Material_ActionBar_TabText: typing.ClassVar[int] = ...
        Widget_Material_ActionBar_TabView: typing.ClassVar[int] = ...
        Widget_Material_ActionButton: typing.ClassVar[int] = ...
        Widget_Material_ActionButton_CloseMode: typing.ClassVar[int] = ...
        Widget_Material_ActionButton_Overflow: typing.ClassVar[int] = ...
        Widget_Material_ActionMode: typing.ClassVar[int] = ...
        Widget_Material_AutoCompleteTextView: typing.ClassVar[int] = ...
        Widget_Material_Button: typing.ClassVar[int] = ...
        Widget_Material_ButtonBar: typing.ClassVar[int] = ...
        Widget_Material_ButtonBar_AlertDialog: typing.ClassVar[int] = ...
        Widget_Material_Button_Borderless: typing.ClassVar[int] = ...
        Widget_Material_Button_Borderless_Colored: typing.ClassVar[int] = ...
        Widget_Material_Button_Borderless_Small: typing.ClassVar[int] = ...
        Widget_Material_Button_Colored: typing.ClassVar[int] = ...
        Widget_Material_Button_Inset: typing.ClassVar[int] = ...
        Widget_Material_Button_Small: typing.ClassVar[int] = ...
        Widget_Material_Button_Toggle: typing.ClassVar[int] = ...
        Widget_Material_CalendarView: typing.ClassVar[int] = ...
        Widget_Material_CheckedTextView: typing.ClassVar[int] = ...
        Widget_Material_CompoundButton_CheckBox: typing.ClassVar[int] = ...
        Widget_Material_CompoundButton_RadioButton: typing.ClassVar[int] = ...
        Widget_Material_CompoundButton_Star: typing.ClassVar[int] = ...
        Widget_Material_CompoundButton_Switch: typing.ClassVar[int] = ...
        Widget_Material_DatePicker: typing.ClassVar[int] = ...
        Widget_Material_DropDownItem: typing.ClassVar[int] = ...
        Widget_Material_DropDownItem_Spinner: typing.ClassVar[int] = ...
        Widget_Material_EditText: typing.ClassVar[int] = ...
        Widget_Material_ExpandableListView: typing.ClassVar[int] = ...
        Widget_Material_FastScroll: typing.ClassVar[int] = ...
        Widget_Material_GridView: typing.ClassVar[int] = ...
        Widget_Material_HorizontalScrollView: typing.ClassVar[int] = ...
        Widget_Material_ImageButton: typing.ClassVar[int] = ...
        Widget_Material_Light: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionBar: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionBar_Solid: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionBar_TabBar: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionBar_TabText: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionBar_TabView: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionButton: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionButton_CloseMode: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionButton_Overflow: typing.ClassVar[int] = ...
        Widget_Material_Light_ActionMode: typing.ClassVar[int] = ...
        Widget_Material_Light_AutoCompleteTextView: typing.ClassVar[int] = ...
        Widget_Material_Light_Button: typing.ClassVar[int] = ...
        Widget_Material_Light_ButtonBar: typing.ClassVar[int] = ...
        Widget_Material_Light_ButtonBar_AlertDialog: typing.ClassVar[int] = ...
        Widget_Material_Light_Button_Borderless: typing.ClassVar[int] = ...
        Widget_Material_Light_Button_Borderless_Colored: typing.ClassVar[int] = ...
        Widget_Material_Light_Button_Borderless_Small: typing.ClassVar[int] = ...
        Widget_Material_Light_Button_Inset: typing.ClassVar[int] = ...
        Widget_Material_Light_Button_Small: typing.ClassVar[int] = ...
        Widget_Material_Light_Button_Toggle: typing.ClassVar[int] = ...
        Widget_Material_Light_CalendarView: typing.ClassVar[int] = ...
        Widget_Material_Light_CheckedTextView: typing.ClassVar[int] = ...
        Widget_Material_Light_CompoundButton_CheckBox: typing.ClassVar[int] = ...
        Widget_Material_Light_CompoundButton_RadioButton: typing.ClassVar[int] = ...
        Widget_Material_Light_CompoundButton_Star: typing.ClassVar[int] = ...
        Widget_Material_Light_CompoundButton_Switch: typing.ClassVar[int] = ...
        Widget_Material_Light_DatePicker: typing.ClassVar[int] = ...
        Widget_Material_Light_DropDownItem: typing.ClassVar[int] = ...
        Widget_Material_Light_DropDownItem_Spinner: typing.ClassVar[int] = ...
        Widget_Material_Light_EditText: typing.ClassVar[int] = ...
        Widget_Material_Light_ExpandableListView: typing.ClassVar[int] = ...
        Widget_Material_Light_FastScroll: typing.ClassVar[int] = ...
        Widget_Material_Light_GridView: typing.ClassVar[int] = ...
        Widget_Material_Light_HorizontalScrollView: typing.ClassVar[int] = ...
        Widget_Material_Light_ImageButton: typing.ClassVar[int] = ...
        Widget_Material_Light_ListPopupWindow: typing.ClassVar[int] = ...
        Widget_Material_Light_ListView: typing.ClassVar[int] = ...
        Widget_Material_Light_ListView_DropDown: typing.ClassVar[int] = ...
        Widget_Material_Light_MediaRouteButton: typing.ClassVar[int] = ...
        Widget_Material_Light_NumberPicker: typing.ClassVar[int] = ...
        Widget_Material_Light_PopupMenu: typing.ClassVar[int] = ...
        Widget_Material_Light_PopupMenu_Overflow: typing.ClassVar[int] = ...
        Widget_Material_Light_PopupWindow: typing.ClassVar[int] = ...
        Widget_Material_Light_ProgressBar: typing.ClassVar[int] = ...
        Widget_Material_Light_ProgressBar_Horizontal: typing.ClassVar[int] = ...
        Widget_Material_Light_ProgressBar_Inverse: typing.ClassVar[int] = ...
        Widget_Material_Light_ProgressBar_Large: typing.ClassVar[int] = ...
        Widget_Material_Light_ProgressBar_Large_Inverse: typing.ClassVar[int] = ...
        Widget_Material_Light_ProgressBar_Small: typing.ClassVar[int] = ...
        Widget_Material_Light_ProgressBar_Small_Inverse: typing.ClassVar[int] = ...
        Widget_Material_Light_ProgressBar_Small_Title: typing.ClassVar[int] = ...
        Widget_Material_Light_RatingBar: typing.ClassVar[int] = ...
        Widget_Material_Light_RatingBar_Indicator: typing.ClassVar[int] = ...
        Widget_Material_Light_RatingBar_Small: typing.ClassVar[int] = ...
        Widget_Material_Light_ScrollView: typing.ClassVar[int] = ...
        Widget_Material_Light_SearchView: typing.ClassVar[int] = ...
        Widget_Material_Light_SeekBar: typing.ClassVar[int] = ...
        Widget_Material_Light_SegmentedButton: typing.ClassVar[int] = ...
        Widget_Material_Light_Spinner: typing.ClassVar[int] = ...
        Widget_Material_Light_Spinner_Underlined: typing.ClassVar[int] = ...
        Widget_Material_Light_StackView: typing.ClassVar[int] = ...
        Widget_Material_Light_Tab: typing.ClassVar[int] = ...
        Widget_Material_Light_TabWidget: typing.ClassVar[int] = ...
        Widget_Material_Light_TextView: typing.ClassVar[int] = ...
        Widget_Material_Light_TextView_SpinnerItem: typing.ClassVar[int] = ...
        Widget_Material_Light_TimePicker: typing.ClassVar[int] = ...
        Widget_Material_Light_WebTextView: typing.ClassVar[int] = ...
        Widget_Material_Light_WebView: typing.ClassVar[int] = ...
        Widget_Material_ListPopupWindow: typing.ClassVar[int] = ...
        Widget_Material_ListView: typing.ClassVar[int] = ...
        Widget_Material_ListView_DropDown: typing.ClassVar[int] = ...
        Widget_Material_MediaRouteButton: typing.ClassVar[int] = ...
        Widget_Material_NumberPicker: typing.ClassVar[int] = ...
        Widget_Material_PopupMenu: typing.ClassVar[int] = ...
        Widget_Material_PopupMenu_Overflow: typing.ClassVar[int] = ...
        Widget_Material_PopupWindow: typing.ClassVar[int] = ...
        Widget_Material_ProgressBar: typing.ClassVar[int] = ...
        Widget_Material_ProgressBar_Horizontal: typing.ClassVar[int] = ...
        Widget_Material_ProgressBar_Large: typing.ClassVar[int] = ...
        Widget_Material_ProgressBar_Small: typing.ClassVar[int] = ...
        Widget_Material_ProgressBar_Small_Title: typing.ClassVar[int] = ...
        Widget_Material_RatingBar: typing.ClassVar[int] = ...
        Widget_Material_RatingBar_Indicator: typing.ClassVar[int] = ...
        Widget_Material_RatingBar_Small: typing.ClassVar[int] = ...
        Widget_Material_ScrollView: typing.ClassVar[int] = ...
        Widget_Material_SearchView: typing.ClassVar[int] = ...
        Widget_Material_SeekBar: typing.ClassVar[int] = ...
        Widget_Material_SeekBar_Discrete: typing.ClassVar[int] = ...
        Widget_Material_SegmentedButton: typing.ClassVar[int] = ...
        Widget_Material_Spinner: typing.ClassVar[int] = ...
        Widget_Material_Spinner_Underlined: typing.ClassVar[int] = ...
        Widget_Material_StackView: typing.ClassVar[int] = ...
        Widget_Material_Tab: typing.ClassVar[int] = ...
        Widget_Material_TabWidget: typing.ClassVar[int] = ...
        Widget_Material_TextView: typing.ClassVar[int] = ...
        Widget_Material_TextView_SpinnerItem: typing.ClassVar[int] = ...
        Widget_Material_TimePicker: typing.ClassVar[int] = ...
        Widget_Material_Toolbar: typing.ClassVar[int] = ...
        Widget_Material_Toolbar_Button_Navigation: typing.ClassVar[int] = ...
        Widget_Material_WebTextView: typing.ClassVar[int] = ...
        Widget_Material_WebView: typing.ClassVar[int] = ...
        Widget_PopupMenu: typing.ClassVar[int] = ...
        Widget_PopupWindow: typing.ClassVar[int] = ...
        Widget_ProgressBar: typing.ClassVar[int] = ...
        Widget_ProgressBar_Horizontal: typing.ClassVar[int] = ...
        Widget_ProgressBar_Inverse: typing.ClassVar[int] = ...
        Widget_ProgressBar_Large: typing.ClassVar[int] = ...
        Widget_ProgressBar_Large_Inverse: typing.ClassVar[int] = ...
        Widget_ProgressBar_Small: typing.ClassVar[int] = ...
        Widget_ProgressBar_Small_Inverse: typing.ClassVar[int] = ...
        Widget_RatingBar: typing.ClassVar[int] = ...
        Widget_ScrollView: typing.ClassVar[int] = ...
        Widget_SeekBar: typing.ClassVar[int] = ...
        Widget_Spinner: typing.ClassVar[int] = ...
        Widget_Spinner_DropDown: typing.ClassVar[int] = ...
        Widget_StackView: typing.ClassVar[int] = ...
        Widget_TabWidget: typing.ClassVar[int] = ...
        Widget_TextView: typing.ClassVar[int] = ...
        Widget_TextView_PopupMenu: typing.ClassVar[int] = ...
        Widget_TextView_SpinnerItem: typing.ClassVar[int] = ...
        Widget_Toolbar: typing.ClassVar[int] = ...
        Widget_Toolbar_Button_Navigation: typing.ClassVar[int] = ...
        Widget_WebView: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class string(java.lang.Object):
        VideoView_error_button: typing.ClassVar[int] = ...
        VideoView_error_text_invalid_progressive_playback: typing.ClassVar[int] = ...
        VideoView_error_text_unknown: typing.ClassVar[int] = ...
        VideoView_error_title: typing.ClassVar[int] = ...
        autofill: typing.ClassVar[int] = ...
        cancel: typing.ClassVar[int] = ...
        copy: typing.ClassVar[int] = ...
        copyUrl: typing.ClassVar[int] = ...
        cut: typing.ClassVar[int] = ...
        defaultMsisdnAlphaTag: typing.ClassVar[int] = ...
        defaultVoiceMailAlphaTag: typing.ClassVar[int] = ...
        dialog_alert_title: typing.ClassVar[int] = ...
        emptyPhoneNumber: typing.ClassVar[int] = ...
        fingerprint_icon_content_description: typing.ClassVar[int] = ...
        httpErrorBadUrl: typing.ClassVar[int] = ...
        httpErrorUnsupportedScheme: typing.ClassVar[int] = ...
        no: typing.ClassVar[int] = ...
        ok: typing.ClassVar[int] = ...
        paste: typing.ClassVar[int] = ...
        paste_as_plain_text: typing.ClassVar[int] = ...
        search_go: typing.ClassVar[int] = ...
        selectAll: typing.ClassVar[int] = ...
        selectTextMode: typing.ClassVar[int] = ...
        status_bar_notification_info_overflow: typing.ClassVar[int] = ...
        unknownName: typing.ClassVar[int] = ...
        untitled: typing.ClassVar[int] = ...
        yes: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class raw(java.lang.Object):
        def __init__(self) -> None: ...

    class plurals(java.lang.Object):
        def __init__(self) -> None: ...

    class mipmap(java.lang.Object):
        sym_def_app_icon: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class menu(java.lang.Object):
        def __init__(self) -> None: ...

    class layout(java.lang.Object):
        activity_list_item: typing.ClassVar[int] = ...
        browser_link_context_header: typing.ClassVar[int] = ...
        expandable_list_content: typing.ClassVar[int] = ...
        list_content: typing.ClassVar[int] = ...
        preference_category: typing.ClassVar[int] = ...
        select_dialog_item: typing.ClassVar[int] = ...
        select_dialog_multichoice: typing.ClassVar[int] = ...
        select_dialog_singlechoice: typing.ClassVar[int] = ...
        simple_dropdown_item_1line: typing.ClassVar[int] = ...
        simple_expandable_list_item_1: typing.ClassVar[int] = ...
        simple_expandable_list_item_2: typing.ClassVar[int] = ...
        simple_gallery_item: typing.ClassVar[int] = ...
        simple_list_item_1: typing.ClassVar[int] = ...
        simple_list_item_2: typing.ClassVar[int] = ...
        simple_list_item_activated_1: typing.ClassVar[int] = ...
        simple_list_item_activated_2: typing.ClassVar[int] = ...
        simple_list_item_checked: typing.ClassVar[int] = ...
        simple_list_item_multiple_choice: typing.ClassVar[int] = ...
        simple_list_item_single_choice: typing.ClassVar[int] = ...
        simple_selectable_list_item: typing.ClassVar[int] = ...
        simple_spinner_dropdown_item: typing.ClassVar[int] = ...
        simple_spinner_item: typing.ClassVar[int] = ...
        test_list_item: typing.ClassVar[int] = ...
        two_line_list_item: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class interpolator(java.lang.Object):
        accelerate_cubic: typing.ClassVar[int] = ...
        accelerate_decelerate: typing.ClassVar[int] = ...
        accelerate_quad: typing.ClassVar[int] = ...
        accelerate_quint: typing.ClassVar[int] = ...
        anticipate: typing.ClassVar[int] = ...
        anticipate_overshoot: typing.ClassVar[int] = ...
        bounce: typing.ClassVar[int] = ...
        cycle: typing.ClassVar[int] = ...
        decelerate_cubic: typing.ClassVar[int] = ...
        decelerate_quad: typing.ClassVar[int] = ...
        decelerate_quint: typing.ClassVar[int] = ...
        fast_out_extra_slow_in: typing.ClassVar[int] = ...
        fast_out_linear_in: typing.ClassVar[int] = ...
        fast_out_slow_in: typing.ClassVar[int] = ...
        linear: typing.ClassVar[int] = ...
        linear_out_slow_in: typing.ClassVar[int] = ...
        overshoot: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class integer(java.lang.Object):
        config_longAnimTime: typing.ClassVar[int] = ...
        config_mediumAnimTime: typing.ClassVar[int] = ...
        config_shortAnimTime: typing.ClassVar[int] = ...
        status_bar_notification_info_maxnum: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class id(java.lang.Object):
        accessibilityActionContextClick: typing.ClassVar[int] = ...
        accessibilityActionDragCancel: typing.ClassVar[int] = ...
        accessibilityActionDragDrop: typing.ClassVar[int] = ...
        accessibilityActionDragStart: typing.ClassVar[int] = ...
        accessibilityActionHideTooltip: typing.ClassVar[int] = ...
        accessibilityActionImeEnter: typing.ClassVar[int] = ...
        accessibilityActionMoveWindow: typing.ClassVar[int] = ...
        accessibilityActionPageDown: typing.ClassVar[int] = ...
        accessibilityActionPageLeft: typing.ClassVar[int] = ...
        accessibilityActionPageRight: typing.ClassVar[int] = ...
        accessibilityActionPageUp: typing.ClassVar[int] = ...
        accessibilityActionPressAndHold: typing.ClassVar[int] = ...
        accessibilityActionScrollDown: typing.ClassVar[int] = ...
        accessibilityActionScrollInDirection: typing.ClassVar[int] = ...
        accessibilityActionScrollLeft: typing.ClassVar[int] = ...
        accessibilityActionScrollRight: typing.ClassVar[int] = ...
        accessibilityActionScrollToPosition: typing.ClassVar[int] = ...
        accessibilityActionScrollUp: typing.ClassVar[int] = ...
        accessibilityActionSetProgress: typing.ClassVar[int] = ...
        accessibilityActionShowOnScreen: typing.ClassVar[int] = ...
        accessibilityActionShowTextSuggestions: typing.ClassVar[int] = ...
        accessibilityActionShowTooltip: typing.ClassVar[int] = ...
        accessibilitySystemActionBack: typing.ClassVar[int] = ...
        accessibilitySystemActionHome: typing.ClassVar[int] = ...
        accessibilitySystemActionLockScreen: typing.ClassVar[int] = ...
        accessibilitySystemActionNotifications: typing.ClassVar[int] = ...
        accessibilitySystemActionPowerDialog: typing.ClassVar[int] = ...
        accessibilitySystemActionQuickSettings: typing.ClassVar[int] = ...
        accessibilitySystemActionRecents: typing.ClassVar[int] = ...
        accessibilitySystemActionTakeScreenshot: typing.ClassVar[int] = ...
        accessibilitySystemActionToggleSplitScreen: typing.ClassVar[int] = ...
        addToDictionary: typing.ClassVar[int] = ...
        autofill: typing.ClassVar[int] = ...
        background: typing.ClassVar[int] = ...
        bold: typing.ClassVar[int] = ...
        button1: typing.ClassVar[int] = ...
        button2: typing.ClassVar[int] = ...
        button3: typing.ClassVar[int] = ...
        candidatesArea: typing.ClassVar[int] = ...
        checkbox: typing.ClassVar[int] = ...
        closeButton: typing.ClassVar[int] = ...
        content: typing.ClassVar[int] = ...
        copy: typing.ClassVar[int] = ...
        copyUrl: typing.ClassVar[int] = ...
        custom: typing.ClassVar[int] = ...
        cut: typing.ClassVar[int] = ...
        edit: typing.ClassVar[int] = ...
        empty: typing.ClassVar[int] = ...
        extractArea: typing.ClassVar[int] = ...
        hint: typing.ClassVar[int] = ...
        home: typing.ClassVar[int] = ...
        icon1: typing.ClassVar[int] = ...
        icon2: typing.ClassVar[int] = ...
        icon: typing.ClassVar[int] = ...
        icon_frame: typing.ClassVar[int] = ...
        input: typing.ClassVar[int] = ...
        inputArea: typing.ClassVar[int] = ...
        inputExtractAccessories: typing.ClassVar[int] = ...
        inputExtractAction: typing.ClassVar[int] = ...
        inputExtractEditText: typing.ClassVar[int] = ...
        italic: typing.ClassVar[int] = ...
        keyboardView: typing.ClassVar[int] = ...
        list: typing.ClassVar[int] = ...
        list_container: typing.ClassVar[int] = ...
        mask: typing.ClassVar[int] = ...
        message: typing.ClassVar[int] = ...
        navigationBarBackground: typing.ClassVar[int] = ...
        paste: typing.ClassVar[int] = ...
        pasteAsPlainText: typing.ClassVar[int] = ...
        primary: typing.ClassVar[int] = ...
        progress: typing.ClassVar[int] = ...
        redo: typing.ClassVar[int] = ...
        replaceText: typing.ClassVar[int] = ...
        secondaryProgress: typing.ClassVar[int] = ...
        selectAll: typing.ClassVar[int] = ...
        selectTextMode: typing.ClassVar[int] = ...
        selectedIcon: typing.ClassVar[int] = ...
        shareText: typing.ClassVar[int] = ...
        startSelectingText: typing.ClassVar[int] = ...
        statusBarBackground: typing.ClassVar[int] = ...
        stopSelectingText: typing.ClassVar[int] = ...
        summary: typing.ClassVar[int] = ...
        switchInputMethod: typing.ClassVar[int] = ...
        switch_widget: typing.ClassVar[int] = ...
        tabcontent: typing.ClassVar[int] = ...
        tabhost: typing.ClassVar[int] = ...
        tabs: typing.ClassVar[int] = ...
        text1: typing.ClassVar[int] = ...
        text2: typing.ClassVar[int] = ...
        textAssist: typing.ClassVar[int] = ...
        title: typing.ClassVar[int] = ...
        toggle: typing.ClassVar[int] = ...
        underline: typing.ClassVar[int] = ...
        undo: typing.ClassVar[int] = ...
        widget_frame: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class fraction(java.lang.Object):
        def __init__(self) -> None: ...

    class drawable(java.lang.Object):
        alert_dark_frame: typing.ClassVar[int] = ...
        alert_light_frame: typing.ClassVar[int] = ...
        arrow_down_float: typing.ClassVar[int] = ...
        arrow_up_float: typing.ClassVar[int] = ...
        bottom_bar: typing.ClassVar[int] = ...
        btn_default: typing.ClassVar[int] = ...
        btn_default_small: typing.ClassVar[int] = ...
        btn_dialog: typing.ClassVar[int] = ...
        btn_dropdown: typing.ClassVar[int] = ...
        btn_minus: typing.ClassVar[int] = ...
        btn_plus: typing.ClassVar[int] = ...
        btn_radio: typing.ClassVar[int] = ...
        btn_star: typing.ClassVar[int] = ...
        btn_star_big_off: typing.ClassVar[int] = ...
        btn_star_big_on: typing.ClassVar[int] = ...
        button_onoff_indicator_off: typing.ClassVar[int] = ...
        button_onoff_indicator_on: typing.ClassVar[int] = ...
        checkbox_off_background: typing.ClassVar[int] = ...
        checkbox_on_background: typing.ClassVar[int] = ...
        dark_header: typing.ClassVar[int] = ...
        dialog_frame: typing.ClassVar[int] = ...
        dialog_holo_dark_frame: typing.ClassVar[int] = ...
        dialog_holo_light_frame: typing.ClassVar[int] = ...
        divider_horizontal_bright: typing.ClassVar[int] = ...
        divider_horizontal_dark: typing.ClassVar[int] = ...
        divider_horizontal_dim_dark: typing.ClassVar[int] = ...
        divider_horizontal_textfield: typing.ClassVar[int] = ...
        edit_text: typing.ClassVar[int] = ...
        editbox_background: typing.ClassVar[int] = ...
        editbox_background_normal: typing.ClassVar[int] = ...
        editbox_dropdown_dark_frame: typing.ClassVar[int] = ...
        editbox_dropdown_light_frame: typing.ClassVar[int] = ...
        gallery_thumb: typing.ClassVar[int] = ...
        ic_btn_speak_now: typing.ClassVar[int] = ...
        ic_delete: typing.ClassVar[int] = ...
        ic_dialog_alert: typing.ClassVar[int] = ...
        ic_dialog_dialer: typing.ClassVar[int] = ...
        ic_dialog_email: typing.ClassVar[int] = ...
        ic_dialog_info: typing.ClassVar[int] = ...
        ic_dialog_map: typing.ClassVar[int] = ...
        ic_input_add: typing.ClassVar[int] = ...
        ic_input_delete: typing.ClassVar[int] = ...
        ic_input_get: typing.ClassVar[int] = ...
        ic_lock_idle_alarm: typing.ClassVar[int] = ...
        ic_lock_idle_charging: typing.ClassVar[int] = ...
        ic_lock_idle_lock: typing.ClassVar[int] = ...
        ic_lock_idle_low_battery: typing.ClassVar[int] = ...
        ic_lock_lock: typing.ClassVar[int] = ...
        ic_lock_power_off: typing.ClassVar[int] = ...
        ic_lock_silent_mode: typing.ClassVar[int] = ...
        ic_lock_silent_mode_off: typing.ClassVar[int] = ...
        ic_media_ff: typing.ClassVar[int] = ...
        ic_media_next: typing.ClassVar[int] = ...
        ic_media_pause: typing.ClassVar[int] = ...
        ic_media_play: typing.ClassVar[int] = ...
        ic_media_previous: typing.ClassVar[int] = ...
        ic_media_rew: typing.ClassVar[int] = ...
        ic_menu_add: typing.ClassVar[int] = ...
        ic_menu_agenda: typing.ClassVar[int] = ...
        ic_menu_always_landscape_portrait: typing.ClassVar[int] = ...
        ic_menu_call: typing.ClassVar[int] = ...
        ic_menu_camera: typing.ClassVar[int] = ...
        ic_menu_close_clear_cancel: typing.ClassVar[int] = ...
        ic_menu_compass: typing.ClassVar[int] = ...
        ic_menu_crop: typing.ClassVar[int] = ...
        ic_menu_day: typing.ClassVar[int] = ...
        ic_menu_delete: typing.ClassVar[int] = ...
        ic_menu_directions: typing.ClassVar[int] = ...
        ic_menu_edit: typing.ClassVar[int] = ...
        ic_menu_gallery: typing.ClassVar[int] = ...
        ic_menu_help: typing.ClassVar[int] = ...
        ic_menu_info_details: typing.ClassVar[int] = ...
        ic_menu_manage: typing.ClassVar[int] = ...
        ic_menu_mapmode: typing.ClassVar[int] = ...
        ic_menu_month: typing.ClassVar[int] = ...
        ic_menu_more: typing.ClassVar[int] = ...
        ic_menu_my_calendar: typing.ClassVar[int] = ...
        ic_menu_mylocation: typing.ClassVar[int] = ...
        ic_menu_myplaces: typing.ClassVar[int] = ...
        ic_menu_preferences: typing.ClassVar[int] = ...
        ic_menu_recent_history: typing.ClassVar[int] = ...
        ic_menu_report_image: typing.ClassVar[int] = ...
        ic_menu_revert: typing.ClassVar[int] = ...
        ic_menu_rotate: typing.ClassVar[int] = ...
        ic_menu_save: typing.ClassVar[int] = ...
        ic_menu_search: typing.ClassVar[int] = ...
        ic_menu_send: typing.ClassVar[int] = ...
        ic_menu_set_as: typing.ClassVar[int] = ...
        ic_menu_share: typing.ClassVar[int] = ...
        ic_menu_slideshow: typing.ClassVar[int] = ...
        ic_menu_sort_alphabetically: typing.ClassVar[int] = ...
        ic_menu_sort_by_size: typing.ClassVar[int] = ...
        ic_menu_today: typing.ClassVar[int] = ...
        ic_menu_upload: typing.ClassVar[int] = ...
        ic_menu_upload_you_tube: typing.ClassVar[int] = ...
        ic_menu_view: typing.ClassVar[int] = ...
        ic_menu_week: typing.ClassVar[int] = ...
        ic_menu_zoom: typing.ClassVar[int] = ...
        ic_notification_clear_all: typing.ClassVar[int] = ...
        ic_notification_overlay: typing.ClassVar[int] = ...
        ic_partial_secure: typing.ClassVar[int] = ...
        ic_popup_disk_full: typing.ClassVar[int] = ...
        ic_popup_reminder: typing.ClassVar[int] = ...
        ic_popup_sync: typing.ClassVar[int] = ...
        ic_search_category_default: typing.ClassVar[int] = ...
        ic_secure: typing.ClassVar[int] = ...
        list_selector_background: typing.ClassVar[int] = ...
        menu_frame: typing.ClassVar[int] = ...
        menu_full_frame: typing.ClassVar[int] = ...
        menuitem_background: typing.ClassVar[int] = ...
        picture_frame: typing.ClassVar[int] = ...
        presence_audio_away: typing.ClassVar[int] = ...
        presence_audio_busy: typing.ClassVar[int] = ...
        presence_audio_online: typing.ClassVar[int] = ...
        presence_away: typing.ClassVar[int] = ...
        presence_busy: typing.ClassVar[int] = ...
        presence_invisible: typing.ClassVar[int] = ...
        presence_offline: typing.ClassVar[int] = ...
        presence_online: typing.ClassVar[int] = ...
        presence_video_away: typing.ClassVar[int] = ...
        presence_video_busy: typing.ClassVar[int] = ...
        presence_video_online: typing.ClassVar[int] = ...
        progress_horizontal: typing.ClassVar[int] = ...
        progress_indeterminate_horizontal: typing.ClassVar[int] = ...
        radiobutton_off_background: typing.ClassVar[int] = ...
        radiobutton_on_background: typing.ClassVar[int] = ...
        screen_background_dark: typing.ClassVar[int] = ...
        screen_background_dark_transparent: typing.ClassVar[int] = ...
        screen_background_light: typing.ClassVar[int] = ...
        screen_background_light_transparent: typing.ClassVar[int] = ...
        spinner_background: typing.ClassVar[int] = ...
        spinner_dropdown_background: typing.ClassVar[int] = ...
        star_big_off: typing.ClassVar[int] = ...
        star_big_on: typing.ClassVar[int] = ...
        star_off: typing.ClassVar[int] = ...
        star_on: typing.ClassVar[int] = ...
        stat_notify_call_mute: typing.ClassVar[int] = ...
        stat_notify_chat: typing.ClassVar[int] = ...
        stat_notify_error: typing.ClassVar[int] = ...
        stat_notify_missed_call: typing.ClassVar[int] = ...
        stat_notify_more: typing.ClassVar[int] = ...
        stat_notify_sdcard: typing.ClassVar[int] = ...
        stat_notify_sdcard_prepare: typing.ClassVar[int] = ...
        stat_notify_sdcard_usb: typing.ClassVar[int] = ...
        stat_notify_sync: typing.ClassVar[int] = ...
        stat_notify_sync_noanim: typing.ClassVar[int] = ...
        stat_notify_voicemail: typing.ClassVar[int] = ...
        stat_sys_data_bluetooth: typing.ClassVar[int] = ...
        stat_sys_download: typing.ClassVar[int] = ...
        stat_sys_download_done: typing.ClassVar[int] = ...
        stat_sys_headset: typing.ClassVar[int] = ...
        stat_sys_phone_call: typing.ClassVar[int] = ...
        stat_sys_phone_call_forward: typing.ClassVar[int] = ...
        stat_sys_phone_call_on_hold: typing.ClassVar[int] = ...
        stat_sys_speakerphone: typing.ClassVar[int] = ...
        stat_sys_upload: typing.ClassVar[int] = ...
        stat_sys_upload_done: typing.ClassVar[int] = ...
        stat_sys_vp_phone_call: typing.ClassVar[int] = ...
        stat_sys_vp_phone_call_on_hold: typing.ClassVar[int] = ...
        stat_sys_warning: typing.ClassVar[int] = ...
        status_bar_item_app_background: typing.ClassVar[int] = ...
        status_bar_item_background: typing.ClassVar[int] = ...
        sym_action_call: typing.ClassVar[int] = ...
        sym_action_chat: typing.ClassVar[int] = ...
        sym_action_email: typing.ClassVar[int] = ...
        sym_call_incoming: typing.ClassVar[int] = ...
        sym_call_missed: typing.ClassVar[int] = ...
        sym_call_outgoing: typing.ClassVar[int] = ...
        sym_contact_card: typing.ClassVar[int] = ...
        sym_def_app_icon: typing.ClassVar[int] = ...
        title_bar: typing.ClassVar[int] = ...
        title_bar_tall: typing.ClassVar[int] = ...
        toast_frame: typing.ClassVar[int] = ...
        zoom_plate: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class dimen(java.lang.Object):
        app_icon_size: typing.ClassVar[int] = ...
        dialog_min_width_major: typing.ClassVar[int] = ...
        dialog_min_width_minor: typing.ClassVar[int] = ...
        notification_large_icon_height: typing.ClassVar[int] = ...
        notification_large_icon_width: typing.ClassVar[int] = ...
        system_app_widget_background_radius: typing.ClassVar[int] = ...
        system_app_widget_inner_radius: typing.ClassVar[int] = ...
        thumbnail_height: typing.ClassVar[int] = ...
        thumbnail_width: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class color(java.lang.Object):
        background_dark: typing.ClassVar[int] = ...
        background_light: typing.ClassVar[int] = ...
        black: typing.ClassVar[int] = ...
        darker_gray: typing.ClassVar[int] = ...
        holo_blue_bright: typing.ClassVar[int] = ...
        holo_blue_dark: typing.ClassVar[int] = ...
        holo_blue_light: typing.ClassVar[int] = ...
        holo_green_dark: typing.ClassVar[int] = ...
        holo_green_light: typing.ClassVar[int] = ...
        holo_orange_dark: typing.ClassVar[int] = ...
        holo_orange_light: typing.ClassVar[int] = ...
        holo_purple: typing.ClassVar[int] = ...
        holo_red_dark: typing.ClassVar[int] = ...
        holo_red_light: typing.ClassVar[int] = ...
        primary_text_dark: typing.ClassVar[int] = ...
        primary_text_dark_nodisable: typing.ClassVar[int] = ...
        primary_text_light: typing.ClassVar[int] = ...
        primary_text_light_nodisable: typing.ClassVar[int] = ...
        secondary_text_dark: typing.ClassVar[int] = ...
        secondary_text_dark_nodisable: typing.ClassVar[int] = ...
        secondary_text_light: typing.ClassVar[int] = ...
        secondary_text_light_nodisable: typing.ClassVar[int] = ...
        system_accent1_0: typing.ClassVar[int] = ...
        system_accent1_1000: typing.ClassVar[int] = ...
        system_accent1_100: typing.ClassVar[int] = ...
        system_accent1_10: typing.ClassVar[int] = ...
        system_accent1_200: typing.ClassVar[int] = ...
        system_accent1_300: typing.ClassVar[int] = ...
        system_accent1_400: typing.ClassVar[int] = ...
        system_accent1_500: typing.ClassVar[int] = ...
        system_accent1_50: typing.ClassVar[int] = ...
        system_accent1_600: typing.ClassVar[int] = ...
        system_accent1_700: typing.ClassVar[int] = ...
        system_accent1_800: typing.ClassVar[int] = ...
        system_accent1_900: typing.ClassVar[int] = ...
        system_accent2_0: typing.ClassVar[int] = ...
        system_accent2_1000: typing.ClassVar[int] = ...
        system_accent2_100: typing.ClassVar[int] = ...
        system_accent2_10: typing.ClassVar[int] = ...
        system_accent2_200: typing.ClassVar[int] = ...
        system_accent2_300: typing.ClassVar[int] = ...
        system_accent2_400: typing.ClassVar[int] = ...
        system_accent2_500: typing.ClassVar[int] = ...
        system_accent2_50: typing.ClassVar[int] = ...
        system_accent2_600: typing.ClassVar[int] = ...
        system_accent2_700: typing.ClassVar[int] = ...
        system_accent2_800: typing.ClassVar[int] = ...
        system_accent2_900: typing.ClassVar[int] = ...
        system_accent3_0: typing.ClassVar[int] = ...
        system_accent3_1000: typing.ClassVar[int] = ...
        system_accent3_100: typing.ClassVar[int] = ...
        system_accent3_10: typing.ClassVar[int] = ...
        system_accent3_200: typing.ClassVar[int] = ...
        system_accent3_300: typing.ClassVar[int] = ...
        system_accent3_400: typing.ClassVar[int] = ...
        system_accent3_500: typing.ClassVar[int] = ...
        system_accent3_50: typing.ClassVar[int] = ...
        system_accent3_600: typing.ClassVar[int] = ...
        system_accent3_700: typing.ClassVar[int] = ...
        system_accent3_800: typing.ClassVar[int] = ...
        system_accent3_900: typing.ClassVar[int] = ...
        system_background_dark: typing.ClassVar[int] = ...
        system_background_light: typing.ClassVar[int] = ...
        system_control_activated_dark: typing.ClassVar[int] = ...
        system_control_activated_light: typing.ClassVar[int] = ...
        system_control_highlight_dark: typing.ClassVar[int] = ...
        system_control_highlight_light: typing.ClassVar[int] = ...
        system_control_normal_dark: typing.ClassVar[int] = ...
        system_control_normal_light: typing.ClassVar[int] = ...
        system_error_0: typing.ClassVar[int] = ...
        system_error_1000: typing.ClassVar[int] = ...
        system_error_100: typing.ClassVar[int] = ...
        system_error_10: typing.ClassVar[int] = ...
        system_error_200: typing.ClassVar[int] = ...
        system_error_300: typing.ClassVar[int] = ...
        system_error_400: typing.ClassVar[int] = ...
        system_error_500: typing.ClassVar[int] = ...
        system_error_50: typing.ClassVar[int] = ...
        system_error_600: typing.ClassVar[int] = ...
        system_error_700: typing.ClassVar[int] = ...
        system_error_800: typing.ClassVar[int] = ...
        system_error_900: typing.ClassVar[int] = ...
        system_error_container_dark: typing.ClassVar[int] = ...
        system_error_container_light: typing.ClassVar[int] = ...
        system_error_dark: typing.ClassVar[int] = ...
        system_error_light: typing.ClassVar[int] = ...
        system_neutral1_0: typing.ClassVar[int] = ...
        system_neutral1_1000: typing.ClassVar[int] = ...
        system_neutral1_100: typing.ClassVar[int] = ...
        system_neutral1_10: typing.ClassVar[int] = ...
        system_neutral1_200: typing.ClassVar[int] = ...
        system_neutral1_300: typing.ClassVar[int] = ...
        system_neutral1_400: typing.ClassVar[int] = ...
        system_neutral1_500: typing.ClassVar[int] = ...
        system_neutral1_50: typing.ClassVar[int] = ...
        system_neutral1_600: typing.ClassVar[int] = ...
        system_neutral1_700: typing.ClassVar[int] = ...
        system_neutral1_800: typing.ClassVar[int] = ...
        system_neutral1_900: typing.ClassVar[int] = ...
        system_neutral2_0: typing.ClassVar[int] = ...
        system_neutral2_1000: typing.ClassVar[int] = ...
        system_neutral2_100: typing.ClassVar[int] = ...
        system_neutral2_10: typing.ClassVar[int] = ...
        system_neutral2_200: typing.ClassVar[int] = ...
        system_neutral2_300: typing.ClassVar[int] = ...
        system_neutral2_400: typing.ClassVar[int] = ...
        system_neutral2_500: typing.ClassVar[int] = ...
        system_neutral2_50: typing.ClassVar[int] = ...
        system_neutral2_600: typing.ClassVar[int] = ...
        system_neutral2_700: typing.ClassVar[int] = ...
        system_neutral2_800: typing.ClassVar[int] = ...
        system_neutral2_900: typing.ClassVar[int] = ...
        system_on_background_dark: typing.ClassVar[int] = ...
        system_on_background_light: typing.ClassVar[int] = ...
        system_on_error_container_dark: typing.ClassVar[int] = ...
        system_on_error_container_light: typing.ClassVar[int] = ...
        system_on_error_dark: typing.ClassVar[int] = ...
        system_on_error_light: typing.ClassVar[int] = ...
        system_on_primary_container_dark: typing.ClassVar[int] = ...
        system_on_primary_container_light: typing.ClassVar[int] = ...
        system_on_primary_dark: typing.ClassVar[int] = ...
        system_on_primary_fixed: typing.ClassVar[int] = ...
        system_on_primary_fixed_variant: typing.ClassVar[int] = ...
        system_on_primary_light: typing.ClassVar[int] = ...
        system_on_secondary_container_dark: typing.ClassVar[int] = ...
        system_on_secondary_container_light: typing.ClassVar[int] = ...
        system_on_secondary_dark: typing.ClassVar[int] = ...
        system_on_secondary_fixed: typing.ClassVar[int] = ...
        system_on_secondary_fixed_variant: typing.ClassVar[int] = ...
        system_on_secondary_light: typing.ClassVar[int] = ...
        system_on_surface_dark: typing.ClassVar[int] = ...
        system_on_surface_disabled: typing.ClassVar[int] = ...
        system_on_surface_light: typing.ClassVar[int] = ...
        system_on_surface_variant_dark: typing.ClassVar[int] = ...
        system_on_surface_variant_light: typing.ClassVar[int] = ...
        system_on_tertiary_container_dark: typing.ClassVar[int] = ...
        system_on_tertiary_container_light: typing.ClassVar[int] = ...
        system_on_tertiary_dark: typing.ClassVar[int] = ...
        system_on_tertiary_fixed: typing.ClassVar[int] = ...
        system_on_tertiary_fixed_variant: typing.ClassVar[int] = ...
        system_on_tertiary_light: typing.ClassVar[int] = ...
        system_outline_dark: typing.ClassVar[int] = ...
        system_outline_disabled: typing.ClassVar[int] = ...
        system_outline_light: typing.ClassVar[int] = ...
        system_outline_variant_dark: typing.ClassVar[int] = ...
        system_outline_variant_light: typing.ClassVar[int] = ...
        system_palette_key_color_neutral_dark: typing.ClassVar[int] = ...
        system_palette_key_color_neutral_light: typing.ClassVar[int] = ...
        system_palette_key_color_neutral_variant_dark: typing.ClassVar[int] = ...
        system_palette_key_color_neutral_variant_light: typing.ClassVar[int] = ...
        system_palette_key_color_primary_dark: typing.ClassVar[int] = ...
        system_palette_key_color_primary_light: typing.ClassVar[int] = ...
        system_palette_key_color_secondary_dark: typing.ClassVar[int] = ...
        system_palette_key_color_secondary_light: typing.ClassVar[int] = ...
        system_palette_key_color_tertiary_dark: typing.ClassVar[int] = ...
        system_palette_key_color_tertiary_light: typing.ClassVar[int] = ...
        system_primary_container_dark: typing.ClassVar[int] = ...
        system_primary_container_light: typing.ClassVar[int] = ...
        system_primary_dark: typing.ClassVar[int] = ...
        system_primary_fixed: typing.ClassVar[int] = ...
        system_primary_fixed_dim: typing.ClassVar[int] = ...
        system_primary_light: typing.ClassVar[int] = ...
        system_secondary_container_dark: typing.ClassVar[int] = ...
        system_secondary_container_light: typing.ClassVar[int] = ...
        system_secondary_dark: typing.ClassVar[int] = ...
        system_secondary_fixed: typing.ClassVar[int] = ...
        system_secondary_fixed_dim: typing.ClassVar[int] = ...
        system_secondary_light: typing.ClassVar[int] = ...
        system_surface_bright_dark: typing.ClassVar[int] = ...
        system_surface_bright_light: typing.ClassVar[int] = ...
        system_surface_container_dark: typing.ClassVar[int] = ...
        system_surface_container_high_dark: typing.ClassVar[int] = ...
        system_surface_container_high_light: typing.ClassVar[int] = ...
        system_surface_container_highest_dark: typing.ClassVar[int] = ...
        system_surface_container_highest_light: typing.ClassVar[int] = ...
        system_surface_container_light: typing.ClassVar[int] = ...
        system_surface_container_low_dark: typing.ClassVar[int] = ...
        system_surface_container_low_light: typing.ClassVar[int] = ...
        system_surface_container_lowest_dark: typing.ClassVar[int] = ...
        system_surface_container_lowest_light: typing.ClassVar[int] = ...
        system_surface_dark: typing.ClassVar[int] = ...
        system_surface_dim_dark: typing.ClassVar[int] = ...
        system_surface_dim_light: typing.ClassVar[int] = ...
        system_surface_disabled: typing.ClassVar[int] = ...
        system_surface_light: typing.ClassVar[int] = ...
        system_surface_variant_dark: typing.ClassVar[int] = ...
        system_surface_variant_light: typing.ClassVar[int] = ...
        system_tertiary_container_dark: typing.ClassVar[int] = ...
        system_tertiary_container_light: typing.ClassVar[int] = ...
        system_tertiary_dark: typing.ClassVar[int] = ...
        system_tertiary_fixed: typing.ClassVar[int] = ...
        system_tertiary_fixed_dim: typing.ClassVar[int] = ...
        system_tertiary_light: typing.ClassVar[int] = ...
        system_text_hint_inverse_dark: typing.ClassVar[int] = ...
        system_text_hint_inverse_light: typing.ClassVar[int] = ...
        system_text_primary_inverse_dark: typing.ClassVar[int] = ...
        system_text_primary_inverse_disable_only_dark: typing.ClassVar[int] = ...
        system_text_primary_inverse_disable_only_light: typing.ClassVar[int] = ...
        system_text_primary_inverse_light: typing.ClassVar[int] = ...
        system_text_secondary_and_tertiary_inverse_dark: typing.ClassVar[int] = ...
        system_text_secondary_and_tertiary_inverse_disabled_dark: typing.ClassVar[int] = ...
        system_text_secondary_and_tertiary_inverse_disabled_light: typing.ClassVar[int] = ...
        system_text_secondary_and_tertiary_inverse_light: typing.ClassVar[int] = ...
        tab_indicator_text: typing.ClassVar[int] = ...
        tertiary_text_dark: typing.ClassVar[int] = ...
        tertiary_text_light: typing.ClassVar[int] = ...
        transparent: typing.ClassVar[int] = ...
        white: typing.ClassVar[int] = ...
        widget_edittext_dark: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class bool(java.lang.Object):
        def __init__(self) -> None: ...

    class attr(java.lang.Object):
        absListViewStyle: typing.ClassVar[int] = ...
        accessibilityDataSensitive: typing.ClassVar[int] = ...
        accessibilityEventTypes: typing.ClassVar[int] = ...
        accessibilityFeedbackType: typing.ClassVar[int] = ...
        accessibilityFlags: typing.ClassVar[int] = ...
        accessibilityHeading: typing.ClassVar[int] = ...
        accessibilityLiveRegion: typing.ClassVar[int] = ...
        accessibilityPaneTitle: typing.ClassVar[int] = ...
        accessibilityTraversalAfter: typing.ClassVar[int] = ...
        accessibilityTraversalBefore: typing.ClassVar[int] = ...
        accountPreferences: typing.ClassVar[int] = ...
        accountType: typing.ClassVar[int] = ...
        action: typing.ClassVar[int] = ...
        actionBarDivider: typing.ClassVar[int] = ...
        actionBarItemBackground: typing.ClassVar[int] = ...
        actionBarPopupTheme: typing.ClassVar[int] = ...
        actionBarSize: typing.ClassVar[int] = ...
        actionBarSplitStyle: typing.ClassVar[int] = ...
        actionBarStyle: typing.ClassVar[int] = ...
        actionBarTabBarStyle: typing.ClassVar[int] = ...
        actionBarTabStyle: typing.ClassVar[int] = ...
        actionBarTabTextStyle: typing.ClassVar[int] = ...
        actionBarTheme: typing.ClassVar[int] = ...
        actionBarWidgetTheme: typing.ClassVar[int] = ...
        actionButtonStyle: typing.ClassVar[int] = ...
        actionDropDownStyle: typing.ClassVar[int] = ...
        actionLayout: typing.ClassVar[int] = ...
        actionMenuTextAppearance: typing.ClassVar[int] = ...
        actionMenuTextColor: typing.ClassVar[int] = ...
        actionModeBackground: typing.ClassVar[int] = ...
        actionModeCloseButtonStyle: typing.ClassVar[int] = ...
        actionModeCloseDrawable: typing.ClassVar[int] = ...
        actionModeCopyDrawable: typing.ClassVar[int] = ...
        actionModeCutDrawable: typing.ClassVar[int] = ...
        actionModeFindDrawable: typing.ClassVar[int] = ...
        actionModePasteDrawable: typing.ClassVar[int] = ...
        actionModeSelectAllDrawable: typing.ClassVar[int] = ...
        actionModeShareDrawable: typing.ClassVar[int] = ...
        actionModeSplitBackground: typing.ClassVar[int] = ...
        actionModeStyle: typing.ClassVar[int] = ...
        actionModeWebSearchDrawable: typing.ClassVar[int] = ...
        actionOverflowButtonStyle: typing.ClassVar[int] = ...
        actionOverflowMenuStyle: typing.ClassVar[int] = ...
        actionProviderClass: typing.ClassVar[int] = ...
        actionViewClass: typing.ClassVar[int] = ...
        activatedBackgroundIndicator: typing.ClassVar[int] = ...
        activityCloseEnterAnimation: typing.ClassVar[int] = ...
        activityCloseExitAnimation: typing.ClassVar[int] = ...
        activityOpenEnterAnimation: typing.ClassVar[int] = ...
        activityOpenExitAnimation: typing.ClassVar[int] = ...
        adServiceTypes: typing.ClassVar[int] = ...
        addPrintersActivity: typing.ClassVar[int] = ...
        addStatesFromChildren: typing.ClassVar[int] = ...
        adjustViewBounds: typing.ClassVar[int] = ...
        advancedPrintOptionsActivity: typing.ClassVar[int] = ...
        alertDialogIcon: typing.ClassVar[int] = ...
        alertDialogStyle: typing.ClassVar[int] = ...
        alertDialogTheme: typing.ClassVar[int] = ...
        alignmentMode: typing.ClassVar[int] = ...
        allContactsName: typing.ClassVar[int] = ...
        allow: typing.ClassVar[int] = ...
        allowAudioPlaybackCapture: typing.ClassVar[int] = ...
        allowBackup: typing.ClassVar[int] = ...
        allowClearUserData: typing.ClassVar[int] = ...
        allowClickWhenDisabled: typing.ClassVar[int] = ...
        allowCrossUidActivitySwitchFromBelow: typing.ClassVar[int] = ...
        allowEmbedded: typing.ClassVar[int] = ...
        allowGameAngleDriver: typing.ClassVar[int] = ...
        allowGameDownscaling: typing.ClassVar[int] = ...
        allowGameFpsOverride: typing.ClassVar[int] = ...
        allowNativeHeapPointerTagging: typing.ClassVar[int] = ...
        allowParallelSyncs: typing.ClassVar[int] = ...
        allowSharedIsolatedProcess: typing.ClassVar[int] = ...
        allowSingleTap: typing.ClassVar[int] = ...
        allowTaskReparenting: typing.ClassVar[int] = ...
        allowUndo: typing.ClassVar[int] = ...
        allowUntrustedActivityEmbedding: typing.ClassVar[int] = ...
        allowUpdateOwnership: typing.ClassVar[int] = ...
        alpha: typing.ClassVar[int] = ...
        alphabeticModifiers: typing.ClassVar[int] = ...
        alphabeticShortcut: typing.ClassVar[int] = ...
        alwaysDrawnWithCache: typing.ClassVar[int] = ...
        alwaysRetainTaskState: typing.ClassVar[int] = ...
        amPmBackgroundColor: typing.ClassVar[int] = ...
        amPmTextColor: typing.ClassVar[int] = ...
        ambientShadowAlpha: typing.ClassVar[int] = ...
        angle: typing.ClassVar[int] = ...
        animateFirstView: typing.ClassVar[int] = ...
        animateLayoutChanges: typing.ClassVar[int] = ...
        animateOnClick: typing.ClassVar[int] = ...
        animatedImageDrawable: typing.ClassVar[int] = ...
        animation: typing.ClassVar[int] = ...
        animationCache: typing.ClassVar[int] = ...
        animationDuration: typing.ClassVar[int] = ...
        animationOrder: typing.ClassVar[int] = ...
        animationResolution: typing.ClassVar[int] = ...
        antialias: typing.ClassVar[int] = ...
        anyDensity: typing.ClassVar[int] = ...
        apduServiceBanner: typing.ClassVar[int] = ...
        apiKey: typing.ClassVar[int] = ...
        appCategory: typing.ClassVar[int] = ...
        appComponentFactory: typing.ClassVar[int] = ...
        attributionTags: typing.ClassVar[int] = ...
        attributionsAreUserVisible: typing.ClassVar[int] = ...
        author: typing.ClassVar[int] = ...
        authorities: typing.ClassVar[int] = ...
        autoAdvanceViewId: typing.ClassVar[int] = ...
        autoCompleteTextViewStyle: typing.ClassVar[int] = ...
        autoHandwritingEnabled: typing.ClassVar[int] = ...
        autoLink: typing.ClassVar[int] = ...
        autoMirrored: typing.ClassVar[int] = ...
        autoRemoveFromRecents: typing.ClassVar[int] = ...
        autoRevokePermissions: typing.ClassVar[int] = ...
        autoSizeMaxTextSize: typing.ClassVar[int] = ...
        autoSizeMinTextSize: typing.ClassVar[int] = ...
        autoSizePresetSizes: typing.ClassVar[int] = ...
        autoSizeStepGranularity: typing.ClassVar[int] = ...
        autoSizeTextType: typing.ClassVar[int] = ...
        autoStart: typing.ClassVar[int] = ...
        autoText: typing.ClassVar[int] = ...
        autoTransact: typing.ClassVar[int] = ...
        autoUrlDetect: typing.ClassVar[int] = ...
        autoVerify: typing.ClassVar[int] = ...
        autofillHints: typing.ClassVar[int] = ...
        autofilledHighlight: typing.ClassVar[int] = ...
        backdropColor: typing.ClassVar[int] = ...
        background: typing.ClassVar[int] = ...
        backgroundDimAmount: typing.ClassVar[int] = ...
        backgroundDimEnabled: typing.ClassVar[int] = ...
        backgroundSplit: typing.ClassVar[int] = ...
        backgroundStacked: typing.ClassVar[int] = ...
        backgroundTint: typing.ClassVar[int] = ...
        backgroundTintMode: typing.ClassVar[int] = ...
        backupAgent: typing.ClassVar[int] = ...
        backupInForeground: typing.ClassVar[int] = ...
        banner: typing.ClassVar[int] = ...
        baseline: typing.ClassVar[int] = ...
        baselineAlignBottom: typing.ClassVar[int] = ...
        baselineAligned: typing.ClassVar[int] = ...
        baselineAlignedChildIndex: typing.ClassVar[int] = ...
        bitmap: typing.ClassVar[int] = ...
        borderlessButtonStyle: typing.ClassVar[int] = ...
        bottom: typing.ClassVar[int] = ...
        bottomBright: typing.ClassVar[int] = ...
        bottomDark: typing.ClassVar[int] = ...
        bottomLeftRadius: typing.ClassVar[int] = ...
        bottomMedium: typing.ClassVar[int] = ...
        bottomOffset: typing.ClassVar[int] = ...
        bottomRightRadius: typing.ClassVar[int] = ...
        breadCrumbShortTitle: typing.ClassVar[int] = ...
        breadCrumbTitle: typing.ClassVar[int] = ...
        breakStrategy: typing.ClassVar[int] = ...
        bufferType: typing.ClassVar[int] = ...
        button: typing.ClassVar[int] = ...
        buttonBarButtonStyle: typing.ClassVar[int] = ...
        buttonBarNegativeButtonStyle: typing.ClassVar[int] = ...
        buttonBarNeutralButtonStyle: typing.ClassVar[int] = ...
        buttonBarPositiveButtonStyle: typing.ClassVar[int] = ...
        buttonBarStyle: typing.ClassVar[int] = ...
        buttonCornerRadius: typing.ClassVar[int] = ...
        buttonGravity: typing.ClassVar[int] = ...
        buttonStyle: typing.ClassVar[int] = ...
        buttonStyleInset: typing.ClassVar[int] = ...
        buttonStyleSmall: typing.ClassVar[int] = ...
        buttonStyleToggle: typing.ClassVar[int] = ...
        buttonTint: typing.ClassVar[int] = ...
        buttonTintMode: typing.ClassVar[int] = ...
        cacheColorHint: typing.ClassVar[int] = ...
        calendarTextColor: typing.ClassVar[int] = ...
        calendarViewShown: typing.ClassVar[int] = ...
        calendarViewStyle: typing.ClassVar[int] = ...
        canControlMagnification: typing.ClassVar[int] = ...
        canDisplayOnRemoteDevices: typing.ClassVar[int] = ...
        canPauseRecording: typing.ClassVar[int] = ...
        canPerformGestures: typing.ClassVar[int] = ...
        canRecord: typing.ClassVar[int] = ...
        canRequestEnhancedWebAccessibility: typing.ClassVar[int] = ...
        canRequestFilterKeyEvents: typing.ClassVar[int] = ...
        canRequestFingerprintGestures: typing.ClassVar[int] = ...
        canRequestTouchExplorationMode: typing.ClassVar[int] = ...
        canRetrieveWindowContent: typing.ClassVar[int] = ...
        canTakeScreenshot: typing.ClassVar[int] = ...
        candidatesTextStyleSpans: typing.ClassVar[int] = ...
        cantSaveState: typing.ClassVar[int] = ...
        capability: typing.ClassVar[int] = ...
        capitalize: typing.ClassVar[int] = ...
        category: typing.ClassVar[int] = ...
        centerBright: typing.ClassVar[int] = ...
        centerColor: typing.ClassVar[int] = ...
        centerDark: typing.ClassVar[int] = ...
        centerMedium: typing.ClassVar[int] = ...
        centerX: typing.ClassVar[int] = ...
        centerY: typing.ClassVar[int] = ...
        certDigest: typing.ClassVar[int] = ...
        checkBoxPreferenceStyle: typing.ClassVar[int] = ...
        checkMark: typing.ClassVar[int] = ...
        checkMarkTint: typing.ClassVar[int] = ...
        checkMarkTintMode: typing.ClassVar[int] = ...
        checkable: typing.ClassVar[int] = ...
        checkableBehavior: typing.ClassVar[int] = ...
        checkboxStyle: typing.ClassVar[int] = ...
        checked: typing.ClassVar[int] = ...
        checkedButton: typing.ClassVar[int] = ...
        checkedTextViewStyle: typing.ClassVar[int] = ...
        childDivider: typing.ClassVar[int] = ...
        childIndicator: typing.ClassVar[int] = ...
        childIndicatorEnd: typing.ClassVar[int] = ...
        childIndicatorLeft: typing.ClassVar[int] = ...
        childIndicatorRight: typing.ClassVar[int] = ...
        childIndicatorStart: typing.ClassVar[int] = ...
        choiceMode: typing.ClassVar[int] = ...
        classLoader: typing.ClassVar[int] = ...
        clearTaskOnLaunch: typing.ClassVar[int] = ...
        clickable: typing.ClassVar[int] = ...
        clipChildren: typing.ClassVar[int] = ...
        clipOrientation: typing.ClassVar[int] = ...
        clipToOutline: typing.ClassVar[int] = ...
        clipToPadding: typing.ClassVar[int] = ...
        closeIcon: typing.ClassVar[int] = ...
        codes: typing.ClassVar[int] = ...
        collapseColumns: typing.ClassVar[int] = ...
        collapseContentDescription: typing.ClassVar[int] = ...
        collapseIcon: typing.ClassVar[int] = ...
        color: typing.ClassVar[int] = ...
        colorAccent: typing.ClassVar[int] = ...
        colorActivatedHighlight: typing.ClassVar[int] = ...
        colorBackground: typing.ClassVar[int] = ...
        colorBackgroundCacheHint: typing.ClassVar[int] = ...
        colorBackgroundFloating: typing.ClassVar[int] = ...
        colorButtonNormal: typing.ClassVar[int] = ...
        colorControlActivated: typing.ClassVar[int] = ...
        colorControlHighlight: typing.ClassVar[int] = ...
        colorControlNormal: typing.ClassVar[int] = ...
        colorEdgeEffect: typing.ClassVar[int] = ...
        colorError: typing.ClassVar[int] = ...
        colorFocusedHighlight: typing.ClassVar[int] = ...
        colorForeground: typing.ClassVar[int] = ...
        colorForegroundInverse: typing.ClassVar[int] = ...
        colorLongPressedHighlight: typing.ClassVar[int] = ...
        colorMode: typing.ClassVar[int] = ...
        colorMultiSelectHighlight: typing.ClassVar[int] = ...
        colorPressedHighlight: typing.ClassVar[int] = ...
        colorPrimary: typing.ClassVar[int] = ...
        colorPrimaryDark: typing.ClassVar[int] = ...
        colorSecondary: typing.ClassVar[int] = ...
        columnCount: typing.ClassVar[int] = ...
        columnDelay: typing.ClassVar[int] = ...
        columnOrderPreserved: typing.ClassVar[int] = ...
        columnWidth: typing.ClassVar[int] = ...
        commitIcon: typing.ClassVar[int] = ...
        compatibleWidthLimitDp: typing.ClassVar[int] = ...
        completionHint: typing.ClassVar[int] = ...
        completionHintView: typing.ClassVar[int] = ...
        completionThreshold: typing.ClassVar[int] = ...
        configChanges: typing.ClassVar[int] = ...
        configure: typing.ClassVar[int] = ...
        constantSize: typing.ClassVar[int] = ...
        content: typing.ClassVar[int] = ...
        contentAgeHint: typing.ClassVar[int] = ...
        contentAuthority: typing.ClassVar[int] = ...
        contentDescription: typing.ClassVar[int] = ...
        contentInsetEnd: typing.ClassVar[int] = ...
        contentInsetEndWithActions: typing.ClassVar[int] = ...
        contentInsetLeft: typing.ClassVar[int] = ...
        contentInsetRight: typing.ClassVar[int] = ...
        contentInsetStart: typing.ClassVar[int] = ...
        contentInsetStartWithNavigation: typing.ClassVar[int] = ...
        contentSensitivity: typing.ClassVar[int] = ...
        contextClickable: typing.ClassVar[int] = ...
        contextDescription: typing.ClassVar[int] = ...
        contextPopupMenuStyle: typing.ClassVar[int] = ...
        contextUri: typing.ClassVar[int] = ...
        controlX1: typing.ClassVar[int] = ...
        controlX2: typing.ClassVar[int] = ...
        controlY1: typing.ClassVar[int] = ...
        controlY2: typing.ClassVar[int] = ...
        countDown: typing.ClassVar[int] = ...
        country: typing.ClassVar[int] = ...
        cropToPadding: typing.ClassVar[int] = ...
        crossProfile: typing.ClassVar[int] = ...
        cursorVisible: typing.ClassVar[int] = ...
        customNavigationLayout: typing.ClassVar[int] = ...
        customTokens: typing.ClassVar[int] = ...
        cycles: typing.ClassVar[int] = ...
        dashGap: typing.ClassVar[int] = ...
        dashWidth: typing.ClassVar[int] = ...
        data: typing.ClassVar[int] = ...
        dataExtractionRules: typing.ClassVar[int] = ...
        datePickerDialogTheme: typing.ClassVar[int] = ...
        datePickerMode: typing.ClassVar[int] = ...
        datePickerStyle: typing.ClassVar[int] = ...
        dateTextAppearance: typing.ClassVar[int] = ...
        dayOfWeekBackground: typing.ClassVar[int] = ...
        dayOfWeekTextAppearance: typing.ClassVar[int] = ...
        debuggable: typing.ClassVar[int] = ...
        defaultFocusHighlightEnabled: typing.ClassVar[int] = ...
        defaultHeight: typing.ClassVar[int] = ...
        defaultLocale: typing.ClassVar[int] = ...
        defaultToDeviceProtectedStorage: typing.ClassVar[int] = ...
        defaultValue: typing.ClassVar[int] = ...
        defaultWidth: typing.ClassVar[int] = ...
        delay: typing.ClassVar[int] = ...
        dependency: typing.ClassVar[int] = ...
        descendantFocusability: typing.ClassVar[int] = ...
        description: typing.ClassVar[int] = ...
        detachWallpaper: typing.ClassVar[int] = ...
        detailColumn: typing.ClassVar[int] = ...
        detailSocialSummary: typing.ClassVar[int] = ...
        detailsElementBackground: typing.ClassVar[int] = ...
        dial: typing.ClassVar[int] = ...
        dialTint: typing.ClassVar[int] = ...
        dialTintMode: typing.ClassVar[int] = ...
        dialogCornerRadius: typing.ClassVar[int] = ...
        dialogIcon: typing.ClassVar[int] = ...
        dialogLayout: typing.ClassVar[int] = ...
        dialogMessage: typing.ClassVar[int] = ...
        dialogPreferenceStyle: typing.ClassVar[int] = ...
        dialogPreferredPadding: typing.ClassVar[int] = ...
        dialogTheme: typing.ClassVar[int] = ...
        dialogTitle: typing.ClassVar[int] = ...
        digits: typing.ClassVar[int] = ...
        directBootAware: typing.ClassVar[int] = ...
        direction: typing.ClassVar[int] = ...
        directionDescriptions: typing.ClassVar[int] = ...
        directionPriority: typing.ClassVar[int] = ...
        disableDependentsState: typing.ClassVar[int] = ...
        disabledAlpha: typing.ClassVar[int] = ...
        displayOptions: typing.ClassVar[int] = ...
        dither: typing.ClassVar[int] = ...
        divider: typing.ClassVar[int] = ...
        dividerHeight: typing.ClassVar[int] = ...
        dividerHorizontal: typing.ClassVar[int] = ...
        dividerPadding: typing.ClassVar[int] = ...
        dividerVertical: typing.ClassVar[int] = ...
        documentLaunchMode: typing.ClassVar[int] = ...
        drawSelectorOnTop: typing.ClassVar[int] = ...
        drawable: typing.ClassVar[int] = ...
        drawableBottom: typing.ClassVar[int] = ...
        drawableEnd: typing.ClassVar[int] = ...
        drawableLeft: typing.ClassVar[int] = ...
        drawablePadding: typing.ClassVar[int] = ...
        drawableRight: typing.ClassVar[int] = ...
        drawableStart: typing.ClassVar[int] = ...
        drawableTint: typing.ClassVar[int] = ...
        drawableTintMode: typing.ClassVar[int] = ...
        drawableTop: typing.ClassVar[int] = ...
        drawingCacheQuality: typing.ClassVar[int] = ...
        dropDownAnchor: typing.ClassVar[int] = ...
        dropDownHeight: typing.ClassVar[int] = ...
        dropDownHintAppearance: typing.ClassVar[int] = ...
        dropDownHorizontalOffset: typing.ClassVar[int] = ...
        dropDownItemStyle: typing.ClassVar[int] = ...
        dropDownListViewStyle: typing.ClassVar[int] = ...
        dropDownSelector: typing.ClassVar[int] = ...
        dropDownSpinnerStyle: typing.ClassVar[int] = ...
        dropDownVerticalOffset: typing.ClassVar[int] = ...
        dropDownWidth: typing.ClassVar[int] = ...
        duplicateParentState: typing.ClassVar[int] = ...
        duration: typing.ClassVar[int] = ...
        editTextBackground: typing.ClassVar[int] = ...
        editTextColor: typing.ClassVar[int] = ...
        editTextPreferenceStyle: typing.ClassVar[int] = ...
        editTextStyle: typing.ClassVar[int] = ...
        editable: typing.ClassVar[int] = ...
        editorExtras: typing.ClassVar[int] = ...
        effectColor: typing.ClassVar[int] = ...
        elegantTextHeight: typing.ClassVar[int] = ...
        elevation: typing.ClassVar[int] = ...
        ellipsize: typing.ClassVar[int] = ...
        ems: typing.ClassVar[int] = ...
        enableOnBackInvokedCallback: typing.ClassVar[int] = ...
        enableTextStylingShortcuts: typing.ClassVar[int] = ...
        enableVrMode: typing.ClassVar[int] = ...
        enabled: typing.ClassVar[int] = ...
        end: typing.ClassVar[int] = ...
        endColor: typing.ClassVar[int] = ...
        endX: typing.ClassVar[int] = ...
        endY: typing.ClassVar[int] = ...
        endYear: typing.ClassVar[int] = ...
        enforceNavigationBarContrast: typing.ClassVar[int] = ...
        enforceStatusBarContrast: typing.ClassVar[int] = ...
        enterFadeDuration: typing.ClassVar[int] = ...
        entries: typing.ClassVar[int] = ...
        entryValues: typing.ClassVar[int] = ...
        eventsInterceptionEnabled: typing.ClassVar[int] = ...
        excludeClass: typing.ClassVar[int] = ...
        excludeFromRecents: typing.ClassVar[int] = ...
        excludeId: typing.ClassVar[int] = ...
        excludeName: typing.ClassVar[int] = ...
        exitFadeDuration: typing.ClassVar[int] = ...
        expandableListPreferredChildIndicatorLeft: typing.ClassVar[int] = ...
        expandableListPreferredChildIndicatorRight: typing.ClassVar[int] = ...
        expandableListPreferredChildPaddingLeft: typing.ClassVar[int] = ...
        expandableListPreferredItemIndicatorLeft: typing.ClassVar[int] = ...
        expandableListPreferredItemIndicatorRight: typing.ClassVar[int] = ...
        expandableListPreferredItemPaddingLeft: typing.ClassVar[int] = ...
        expandableListViewStyle: typing.ClassVar[int] = ...
        expandableListViewWhiteStyle: typing.ClassVar[int] = ...
        exported: typing.ClassVar[int] = ...
        externalService: typing.ClassVar[int] = ...
        extraTension: typing.ClassVar[int] = ...
        extractNativeLibs: typing.ClassVar[int] = ...
        factor: typing.ClassVar[int] = ...
        fadeDuration: typing.ClassVar[int] = ...
        fadeEnabled: typing.ClassVar[int] = ...
        fadeOffset: typing.ClassVar[int] = ...
        fadeScrollbars: typing.ClassVar[int] = ...
        fadingEdge: typing.ClassVar[int] = ...
        fadingEdgeLength: typing.ClassVar[int] = ...
        fadingMode: typing.ClassVar[int] = ...
        fallbackLineSpacing: typing.ClassVar[int] = ...
        fastScrollAlwaysVisible: typing.ClassVar[int] = ...
        fastScrollEnabled: typing.ClassVar[int] = ...
        fastScrollOverlayPosition: typing.ClassVar[int] = ...
        fastScrollPreviewBackgroundLeft: typing.ClassVar[int] = ...
        fastScrollPreviewBackgroundRight: typing.ClassVar[int] = ...
        fastScrollStyle: typing.ClassVar[int] = ...
        fastScrollTextColor: typing.ClassVar[int] = ...
        fastScrollThumbDrawable: typing.ClassVar[int] = ...
        fastScrollTrackDrawable: typing.ClassVar[int] = ...
        fillAfter: typing.ClassVar[int] = ...
        fillAlpha: typing.ClassVar[int] = ...
        fillBefore: typing.ClassVar[int] = ...
        fillColor: typing.ClassVar[int] = ...
        fillEnabled: typing.ClassVar[int] = ...
        fillType: typing.ClassVar[int] = ...
        fillViewport: typing.ClassVar[int] = ...
        filter: typing.ClassVar[int] = ...
        filterTouchesWhenObscured: typing.ClassVar[int] = ...
        fingerprintAuthDrawable: typing.ClassVar[int] = ...
        finishOnCloseSystemDialogs: typing.ClassVar[int] = ...
        finishOnTaskLaunch: typing.ClassVar[int] = ...
        firstBaselineToTopHeight: typing.ClassVar[int] = ...
        firstDayOfWeek: typing.ClassVar[int] = ...
        fitsSystemWindows: typing.ClassVar[int] = ...
        flipInterval: typing.ClassVar[int] = ...
        focusable: typing.ClassVar[int] = ...
        focusableInTouchMode: typing.ClassVar[int] = ...
        focusedByDefault: typing.ClassVar[int] = ...
        focusedMonthDateColor: typing.ClassVar[int] = ...
        focusedSearchResultHighlightColor: typing.ClassVar[int] = ...
        font: typing.ClassVar[int] = ...
        fontFamily: typing.ClassVar[int] = ...
        fontFeatureSettings: typing.ClassVar[int] = ...
        fontProviderAuthority: typing.ClassVar[int] = ...
        fontProviderCerts: typing.ClassVar[int] = ...
        fontProviderPackage: typing.ClassVar[int] = ...
        fontProviderQuery: typing.ClassVar[int] = ...
        fontProviderSystemFontFamily: typing.ClassVar[int] = ...
        fontStyle: typing.ClassVar[int] = ...
        fontVariationSettings: typing.ClassVar[int] = ...
        fontWeight: typing.ClassVar[int] = ...
        footerDividersEnabled: typing.ClassVar[int] = ...
        forceDarkAllowed: typing.ClassVar[int] = ...
        forceHasOverlappingRendering: typing.ClassVar[int] = ...
        forceQueryable: typing.ClassVar[int] = ...
        forceUriPermissions: typing.ClassVar[int] = ...
        foreground: typing.ClassVar[int] = ...
        foregroundGravity: typing.ClassVar[int] = ...
        foregroundServiceType: typing.ClassVar[int] = ...
        foregroundTint: typing.ClassVar[int] = ...
        foregroundTintMode: typing.ClassVar[int] = ...
        format12Hour: typing.ClassVar[int] = ...
        format24Hour: typing.ClassVar[int] = ...
        format: typing.ClassVar[int] = ...
        fraction: typing.ClassVar[int] = ...
        fragment: typing.ClassVar[int] = ...
        fragmentAdvancedPattern: typing.ClassVar[int] = ...
        fragmentAllowEnterTransitionOverlap: typing.ClassVar[int] = ...
        fragmentAllowReturnTransitionOverlap: typing.ClassVar[int] = ...
        fragmentCloseEnterAnimation: typing.ClassVar[int] = ...
        fragmentCloseExitAnimation: typing.ClassVar[int] = ...
        fragmentEnterTransition: typing.ClassVar[int] = ...
        fragmentExitTransition: typing.ClassVar[int] = ...
        fragmentFadeEnterAnimation: typing.ClassVar[int] = ...
        fragmentFadeExitAnimation: typing.ClassVar[int] = ...
        fragmentOpenEnterAnimation: typing.ClassVar[int] = ...
        fragmentOpenExitAnimation: typing.ClassVar[int] = ...
        fragmentPattern: typing.ClassVar[int] = ...
        fragmentPrefix: typing.ClassVar[int] = ...
        fragmentReenterTransition: typing.ClassVar[int] = ...
        fragmentReturnTransition: typing.ClassVar[int] = ...
        fragmentSharedElementEnterTransition: typing.ClassVar[int] = ...
        fragmentSharedElementReturnTransition: typing.ClassVar[int] = ...
        fragmentSuffix: typing.ClassVar[int] = ...
        freezesText: typing.ClassVar[int] = ...
        fromAlpha: typing.ClassVar[int] = ...
        fromDegrees: typing.ClassVar[int] = ...
        fromExtendBottom: typing.ClassVar[int] = ...
        fromExtendLeft: typing.ClassVar[int] = ...
        fromExtendRight: typing.ClassVar[int] = ...
        fromExtendTop: typing.ClassVar[int] = ...
        fromId: typing.ClassVar[int] = ...
        fromScene: typing.ClassVar[int] = ...
        fromXDelta: typing.ClassVar[int] = ...
        fromXScale: typing.ClassVar[int] = ...
        fromYDelta: typing.ClassVar[int] = ...
        fromYScale: typing.ClassVar[int] = ...
        fullBackupContent: typing.ClassVar[int] = ...
        fullBackupOnly: typing.ClassVar[int] = ...
        fullBright: typing.ClassVar[int] = ...
        fullDark: typing.ClassVar[int] = ...
        functionalTest: typing.ClassVar[int] = ...
        galleryItemBackground: typing.ClassVar[int] = ...
        galleryStyle: typing.ClassVar[int] = ...
        gestureColor: typing.ClassVar[int] = ...
        gestureStrokeAngleThreshold: typing.ClassVar[int] = ...
        gestureStrokeLengthThreshold: typing.ClassVar[int] = ...
        gestureStrokeSquarenessThreshold: typing.ClassVar[int] = ...
        gestureStrokeType: typing.ClassVar[int] = ...
        gestureStrokeWidth: typing.ClassVar[int] = ...
        glEsVersion: typing.ClassVar[int] = ...
        goIcon: typing.ClassVar[int] = ...
        gradientRadius: typing.ClassVar[int] = ...
        grantUriPermissions: typing.ClassVar[int] = ...
        gravity: typing.ClassVar[int] = ...
        gridViewStyle: typing.ClassVar[int] = ...
        groupIndicator: typing.ClassVar[int] = ...
        gwpAsanMode: typing.ClassVar[int] = ...
        hand_hour: typing.ClassVar[int] = ...
        hand_hourTint: typing.ClassVar[int] = ...
        hand_hourTintMode: typing.ClassVar[int] = ...
        hand_minute: typing.ClassVar[int] = ...
        hand_minuteTint: typing.ClassVar[int] = ...
        hand_minuteTintMode: typing.ClassVar[int] = ...
        hand_second: typing.ClassVar[int] = ...
        hand_secondTint: typing.ClassVar[int] = ...
        hand_secondTintMode: typing.ClassVar[int] = ...
        handle: typing.ClassVar[int] = ...
        handleProfiling: typing.ClassVar[int] = ...
        handwritingBoundsOffsetBottom: typing.ClassVar[int] = ...
        handwritingBoundsOffsetLeft: typing.ClassVar[int] = ...
        handwritingBoundsOffsetRight: typing.ClassVar[int] = ...
        handwritingBoundsOffsetTop: typing.ClassVar[int] = ...
        hapticFeedbackEnabled: typing.ClassVar[int] = ...
        hardwareAccelerated: typing.ClassVar[int] = ...
        hasCode: typing.ClassVar[int] = ...
        hasFragileUserData: typing.ClassVar[int] = ...
        headerAmPmTextAppearance: typing.ClassVar[int] = ...
        headerBackground: typing.ClassVar[int] = ...
        headerDayOfMonthTextAppearance: typing.ClassVar[int] = ...
        headerDividersEnabled: typing.ClassVar[int] = ...
        headerMonthTextAppearance: typing.ClassVar[int] = ...
        headerTimeTextAppearance: typing.ClassVar[int] = ...
        headerYearTextAppearance: typing.ClassVar[int] = ...
        height: typing.ClassVar[int] = ...
        hideOnContentScroll: typing.ClassVar[int] = ...
        hint: typing.ClassVar[int] = ...
        homeAsUpIndicator: typing.ClassVar[int] = ...
        homeLayout: typing.ClassVar[int] = ...
        horizontalDivider: typing.ClassVar[int] = ...
        horizontalGap: typing.ClassVar[int] = ...
        horizontalScrollViewStyle: typing.ClassVar[int] = ...
        horizontalSpacing: typing.ClassVar[int] = ...
        host: typing.ClassVar[int] = ...
        hotSpotX: typing.ClassVar[int] = ...
        hotSpotY: typing.ClassVar[int] = ...
        htmlDescription: typing.ClassVar[int] = ...
        hyphenationFrequency: typing.ClassVar[int] = ...
        icon: typing.ClassVar[int] = ...
        iconPreview: typing.ClassVar[int] = ...
        iconSpaceReserved: typing.ClassVar[int] = ...
        iconTint: typing.ClassVar[int] = ...
        iconTintMode: typing.ClassVar[int] = ...
        iconifiedByDefault: typing.ClassVar[int] = ...
        id: typing.ClassVar[int] = ...
        identifier: typing.ClassVar[int] = ...
        ignoreGravity: typing.ClassVar[int] = ...
        imageButtonStyle: typing.ClassVar[int] = ...
        imageWellStyle: typing.ClassVar[int] = ...
        imeActionId: typing.ClassVar[int] = ...
        imeActionLabel: typing.ClassVar[int] = ...
        imeExtractEnterAnimation: typing.ClassVar[int] = ...
        imeExtractExitAnimation: typing.ClassVar[int] = ...
        imeFullscreenBackground: typing.ClassVar[int] = ...
        imeOptions: typing.ClassVar[int] = ...
        imeSubtypeExtraValue: typing.ClassVar[int] = ...
        imeSubtypeLocale: typing.ClassVar[int] = ...
        imeSubtypeMode: typing.ClassVar[int] = ...
        immersive: typing.ClassVar[int] = ...
        importantForAccessibility: typing.ClassVar[int] = ...
        importantForAutofill: typing.ClassVar[int] = ...
        importantForContentCapture: typing.ClassVar[int] = ...
        inAnimation: typing.ClassVar[int] = ...
        includeFontPadding: typing.ClassVar[int] = ...
        includeInGlobalSearch: typing.ClassVar[int] = ...
        indeterminate: typing.ClassVar[int] = ...
        indeterminateBehavior: typing.ClassVar[int] = ...
        indeterminateDrawable: typing.ClassVar[int] = ...
        indeterminateDuration: typing.ClassVar[int] = ...
        indeterminateOnly: typing.ClassVar[int] = ...
        indeterminateProgressStyle: typing.ClassVar[int] = ...
        indeterminateTint: typing.ClassVar[int] = ...
        indeterminateTintMode: typing.ClassVar[int] = ...
        indicatorEnd: typing.ClassVar[int] = ...
        indicatorLeft: typing.ClassVar[int] = ...
        indicatorRight: typing.ClassVar[int] = ...
        indicatorStart: typing.ClassVar[int] = ...
        inflatedId: typing.ClassVar[int] = ...
        inheritShowWhenLocked: typing.ClassVar[int] = ...
        initOrder: typing.ClassVar[int] = ...
        initialKeyguardLayout: typing.ClassVar[int] = ...
        initialLayout: typing.ClassVar[int] = ...
        innerRadius: typing.ClassVar[int] = ...
        innerRadiusRatio: typing.ClassVar[int] = ...
        inputMethod: typing.ClassVar[int] = ...
        inputType: typing.ClassVar[int] = ...
        inset: typing.ClassVar[int] = ...
        insetBottom: typing.ClassVar[int] = ...
        insetLeft: typing.ClassVar[int] = ...
        insetRight: typing.ClassVar[int] = ...
        insetTop: typing.ClassVar[int] = ...
        installLocation: typing.ClassVar[int] = ...
        intentMatchingFlags: typing.ClassVar[int] = ...
        interactiveUiTimeout: typing.ClassVar[int] = ...
        interpolator: typing.ClassVar[int] = ...
        intro: typing.ClassVar[int] = ...
        isAccessibilityTool: typing.ClassVar[int] = ...
        isAlwaysSyncable: typing.ClassVar[int] = ...
        isAsciiCapable: typing.ClassVar[int] = ...
        isAuxiliary: typing.ClassVar[int] = ...
        isCredential: typing.ClassVar[int] = ...
        isDefault: typing.ClassVar[int] = ...
        isFeatureSplit: typing.ClassVar[int] = ...
        isGame: typing.ClassVar[int] = ...
        isIndicator: typing.ClassVar[int] = ...
        isLightTheme: typing.ClassVar[int] = ...
        isModifier: typing.ClassVar[int] = ...
        isRepeatable: typing.ClassVar[int] = ...
        isScrollContainer: typing.ClassVar[int] = ...
        isSplitRequired: typing.ClassVar[int] = ...
        isStatic: typing.ClassVar[int] = ...
        isSticky: typing.ClassVar[int] = ...
        isolatedProcess: typing.ClassVar[int] = ...
        isolatedSplits: typing.ClassVar[int] = ...
        itemBackground: typing.ClassVar[int] = ...
        itemIconDisabledAlpha: typing.ClassVar[int] = ...
        itemPadding: typing.ClassVar[int] = ...
        itemTextAppearance: typing.ClassVar[int] = ...
        justificationMode: typing.ClassVar[int] = ...
        keepScreenOn: typing.ClassVar[int] = ...
        key: typing.ClassVar[int] = ...
        keyBackground: typing.ClassVar[int] = ...
        keyEdgeFlags: typing.ClassVar[int] = ...
        keyHeight: typing.ClassVar[int] = ...
        keyIcon: typing.ClassVar[int] = ...
        keyLabel: typing.ClassVar[int] = ...
        keyOutputText: typing.ClassVar[int] = ...
        keyPreviewHeight: typing.ClassVar[int] = ...
        keyPreviewLayout: typing.ClassVar[int] = ...
        keyPreviewOffset: typing.ClassVar[int] = ...
        keySet: typing.ClassVar[int] = ...
        keyTextColor: typing.ClassVar[int] = ...
        keyTextSize: typing.ClassVar[int] = ...
        keyWidth: typing.ClassVar[int] = ...
        keyboardLayout: typing.ClassVar[int] = ...
        keyboardLayoutType: typing.ClassVar[int] = ...
        keyboardLocale: typing.ClassVar[int] = ...
        keyboardMode: typing.ClassVar[int] = ...
        keyboardNavigationCluster: typing.ClassVar[int] = ...
        keycode: typing.ClassVar[int] = ...
        killAfterRestore: typing.ClassVar[int] = ...
        knownActivityEmbeddingCerts: typing.ClassVar[int] = ...
        knownCerts: typing.ClassVar[int] = ...
        lStar: typing.ClassVar[int] = ...
        label: typing.ClassVar[int] = ...
        labelFor: typing.ClassVar[int] = ...
        labelTextSize: typing.ClassVar[int] = ...
        languageSettingsActivity: typing.ClassVar[int] = ...
        languageTag: typing.ClassVar[int] = ...
        largeHeap: typing.ClassVar[int] = ...
        largeScreens: typing.ClassVar[int] = ...
        largestWidthLimitDp: typing.ClassVar[int] = ...
        lastBaselineToBottomHeight: typing.ClassVar[int] = ...
        launchMode: typing.ClassVar[int] = ...
        launchTaskBehindSourceAnimation: typing.ClassVar[int] = ...
        launchTaskBehindTargetAnimation: typing.ClassVar[int] = ...
        layerType: typing.ClassVar[int] = ...
        layout: typing.ClassVar[int] = ...
        layoutAnimation: typing.ClassVar[int] = ...
        layoutDirection: typing.ClassVar[int] = ...
        layoutLabel: typing.ClassVar[int] = ...
        layoutMode: typing.ClassVar[int] = ...
        layout_above: typing.ClassVar[int] = ...
        layout_alignBaseline: typing.ClassVar[int] = ...
        layout_alignBottom: typing.ClassVar[int] = ...
        layout_alignEnd: typing.ClassVar[int] = ...
        layout_alignLeft: typing.ClassVar[int] = ...
        layout_alignParentBottom: typing.ClassVar[int] = ...
        layout_alignParentEnd: typing.ClassVar[int] = ...
        layout_alignParentLeft: typing.ClassVar[int] = ...
        layout_alignParentRight: typing.ClassVar[int] = ...
        layout_alignParentStart: typing.ClassVar[int] = ...
        layout_alignParentTop: typing.ClassVar[int] = ...
        layout_alignRight: typing.ClassVar[int] = ...
        layout_alignStart: typing.ClassVar[int] = ...
        layout_alignTop: typing.ClassVar[int] = ...
        layout_alignWithParentIfMissing: typing.ClassVar[int] = ...
        layout_below: typing.ClassVar[int] = ...
        layout_centerHorizontal: typing.ClassVar[int] = ...
        layout_centerInParent: typing.ClassVar[int] = ...
        layout_centerVertical: typing.ClassVar[int] = ...
        layout_column: typing.ClassVar[int] = ...
        layout_columnSpan: typing.ClassVar[int] = ...
        layout_columnWeight: typing.ClassVar[int] = ...
        layout_gravity: typing.ClassVar[int] = ...
        layout_height: typing.ClassVar[int] = ...
        layout_margin: typing.ClassVar[int] = ...
        layout_marginBottom: typing.ClassVar[int] = ...
        layout_marginEnd: typing.ClassVar[int] = ...
        layout_marginHorizontal: typing.ClassVar[int] = ...
        layout_marginLeft: typing.ClassVar[int] = ...
        layout_marginRight: typing.ClassVar[int] = ...
        layout_marginStart: typing.ClassVar[int] = ...
        layout_marginTop: typing.ClassVar[int] = ...
        layout_marginVertical: typing.ClassVar[int] = ...
        layout_row: typing.ClassVar[int] = ...
        layout_rowSpan: typing.ClassVar[int] = ...
        layout_rowWeight: typing.ClassVar[int] = ...
        layout_scale: typing.ClassVar[int] = ...
        layout_span: typing.ClassVar[int] = ...
        layout_toEndOf: typing.ClassVar[int] = ...
        layout_toLeftOf: typing.ClassVar[int] = ...
        layout_toRightOf: typing.ClassVar[int] = ...
        layout_toStartOf: typing.ClassVar[int] = ...
        layout_weight: typing.ClassVar[int] = ...
        layout_width: typing.ClassVar[int] = ...
        layout_x: typing.ClassVar[int] = ...
        layout_y: typing.ClassVar[int] = ...
        left: typing.ClassVar[int] = ...
        letterSpacing: typing.ClassVar[int] = ...
        level: typing.ClassVar[int] = ...
        lineBreakStyle: typing.ClassVar[int] = ...
        lineBreakWordStyle: typing.ClassVar[int] = ...
        lineHeight: typing.ClassVar[int] = ...
        lineSpacingExtra: typing.ClassVar[int] = ...
        lineSpacingMultiplier: typing.ClassVar[int] = ...
        lines: typing.ClassVar[int] = ...
        linksClickable: typing.ClassVar[int] = ...
        listChoiceBackgroundIndicator: typing.ClassVar[int] = ...
        listChoiceIndicatorMultiple: typing.ClassVar[int] = ...
        listChoiceIndicatorSingle: typing.ClassVar[int] = ...
        listDivider: typing.ClassVar[int] = ...
        listDividerAlertDialog: typing.ClassVar[int] = ...
        listMenuViewStyle: typing.ClassVar[int] = ...
        listPopupWindowStyle: typing.ClassVar[int] = ...
        listPreferredItemHeight: typing.ClassVar[int] = ...
        listPreferredItemHeightLarge: typing.ClassVar[int] = ...
        listPreferredItemHeightSmall: typing.ClassVar[int] = ...
        listPreferredItemPaddingEnd: typing.ClassVar[int] = ...
        listPreferredItemPaddingLeft: typing.ClassVar[int] = ...
        listPreferredItemPaddingRight: typing.ClassVar[int] = ...
        listPreferredItemPaddingStart: typing.ClassVar[int] = ...
        listSelector: typing.ClassVar[int] = ...
        listSeparatorTextViewStyle: typing.ClassVar[int] = ...
        listViewStyle: typing.ClassVar[int] = ...
        listViewWhiteStyle: typing.ClassVar[int] = ...
        localeConfig: typing.ClassVar[int] = ...
        lockTaskMode: typing.ClassVar[int] = ...
        logo: typing.ClassVar[int] = ...
        logoDescription: typing.ClassVar[int] = ...
        longClickable: typing.ClassVar[int] = ...
        loopViews: typing.ClassVar[int] = ...
        manageSpaceActivity: typing.ClassVar[int] = ...
        mapViewStyle: typing.ClassVar[int] = ...
        marqueeRepeatLimit: typing.ClassVar[int] = ...
        matchOrder: typing.ClassVar[int] = ...
        max: typing.ClassVar[int] = ...
        maxAspectRatio: typing.ClassVar[int] = ...
        maxButtonHeight: typing.ClassVar[int] = ...
        maxDate: typing.ClassVar[int] = ...
        maxEms: typing.ClassVar[int] = ...
        maxHeight: typing.ClassVar[int] = ...
        maxItemsPerRow: typing.ClassVar[int] = ...
        maxLength: typing.ClassVar[int] = ...
        maxLevel: typing.ClassVar[int] = ...
        maxLines: typing.ClassVar[int] = ...
        maxLongVersionCode: typing.ClassVar[int] = ...
        maxRecents: typing.ClassVar[int] = ...
        maxResizeHeight: typing.ClassVar[int] = ...
        maxResizeWidth: typing.ClassVar[int] = ...
        maxRows: typing.ClassVar[int] = ...
        maxSdkVersion: typing.ClassVar[int] = ...
        maxWidth: typing.ClassVar[int] = ...
        maximumAngle: typing.ClassVar[int] = ...
        measureAllChildren: typing.ClassVar[int] = ...
        measureWithLargestChild: typing.ClassVar[int] = ...
        mediaRouteButtonStyle: typing.ClassVar[int] = ...
        mediaRouteTypes: typing.ClassVar[int] = ...
        memtagMode: typing.ClassVar[int] = ...
        menuCategory: typing.ClassVar[int] = ...
        mimeGroup: typing.ClassVar[int] = ...
        mimeType: typing.ClassVar[int] = ...
        min: typing.ClassVar[int] = ...
        minAspectRatio: typing.ClassVar[int] = ...
        minDate: typing.ClassVar[int] = ...
        minEms: typing.ClassVar[int] = ...
        minHeight: typing.ClassVar[int] = ...
        minLevel: typing.ClassVar[int] = ...
        minLines: typing.ClassVar[int] = ...
        minResizeHeight: typing.ClassVar[int] = ...
        minResizeWidth: typing.ClassVar[int] = ...
        minSdkVersion: typing.ClassVar[int] = ...
        minWidth: typing.ClassVar[int] = ...
        minimumHorizontalAngle: typing.ClassVar[int] = ...
        minimumVerticalAngle: typing.ClassVar[int] = ...
        mipMap: typing.ClassVar[int] = ...
        mirrorForRtl: typing.ClassVar[int] = ...
        mode: typing.ClassVar[int] = ...
        moreIcon: typing.ClassVar[int] = ...
        multiArch: typing.ClassVar[int] = ...
        multiprocess: typing.ClassVar[int] = ...
        name: typing.ClassVar[int] = ...
        nativeHeapZeroInitialized: typing.ClassVar[int] = ...
        navigationBarColor: typing.ClassVar[int] = ...
        navigationBarDividerColor: typing.ClassVar[int] = ...
        navigationContentDescription: typing.ClassVar[int] = ...
        navigationIcon: typing.ClassVar[int] = ...
        navigationMode: typing.ClassVar[int] = ...
        negativeButtonText: typing.ClassVar[int] = ...
        nestedScrollingEnabled: typing.ClassVar[int] = ...
        networkSecurityConfig: typing.ClassVar[int] = ...
        nextClusterForward: typing.ClassVar[int] = ...
        nextFocusDown: typing.ClassVar[int] = ...
        nextFocusForward: typing.ClassVar[int] = ...
        nextFocusLeft: typing.ClassVar[int] = ...
        nextFocusRight: typing.ClassVar[int] = ...
        nextFocusUp: typing.ClassVar[int] = ...
        noHistory: typing.ClassVar[int] = ...
        nonInteractiveUiTimeout: typing.ClassVar[int] = ...
        normalScreens: typing.ClassVar[int] = ...
        notificationTimeout: typing.ClassVar[int] = ...
        numColumns: typing.ClassVar[int] = ...
        numStars: typing.ClassVar[int] = ...
        numberPickerStyle: typing.ClassVar[int] = ...
        numbersBackgroundColor: typing.ClassVar[int] = ...
        numbersInnerTextColor: typing.ClassVar[int] = ...
        numbersSelectorColor: typing.ClassVar[int] = ...
        numbersTextColor: typing.ClassVar[int] = ...
        numeric: typing.ClassVar[int] = ...
        numericModifiers: typing.ClassVar[int] = ...
        numericShortcut: typing.ClassVar[int] = ...
        offset: typing.ClassVar[int] = ...
        onClick: typing.ClassVar[int] = ...
        oneshot: typing.ClassVar[int] = ...
        opacity: typing.ClassVar[int] = ...
        opticalInsetBottom: typing.ClassVar[int] = ...
        opticalInsetLeft: typing.ClassVar[int] = ...
        opticalInsetRight: typing.ClassVar[int] = ...
        opticalInsetTop: typing.ClassVar[int] = ...
        order: typing.ClassVar[int] = ...
        orderInCategory: typing.ClassVar[int] = ...
        ordering: typing.ClassVar[int] = ...
        orderingFromXml: typing.ClassVar[int] = ...
        orientation: typing.ClassVar[int] = ...
        outAnimation: typing.ClassVar[int] = ...
        outlineAmbientShadowColor: typing.ClassVar[int] = ...
        outlineProvider: typing.ClassVar[int] = ...
        outlineSpotShadowColor: typing.ClassVar[int] = ...
        overScrollFooter: typing.ClassVar[int] = ...
        overScrollHeader: typing.ClassVar[int] = ...
        overScrollMode: typing.ClassVar[int] = ...
        overlapAnchor: typing.ClassVar[int] = ...
        overridesImplicitlyEnabledSubtype: typing.ClassVar[int] = ...
        packageNames: typing.ClassVar[int] = ...
        packageType: typing.ClassVar[int] = ...
        padding: typing.ClassVar[int] = ...
        paddingBottom: typing.ClassVar[int] = ...
        paddingEnd: typing.ClassVar[int] = ...
        paddingHorizontal: typing.ClassVar[int] = ...
        paddingLeft: typing.ClassVar[int] = ...
        paddingMode: typing.ClassVar[int] = ...
        paddingRight: typing.ClassVar[int] = ...
        paddingStart: typing.ClassVar[int] = ...
        paddingTop: typing.ClassVar[int] = ...
        paddingVertical: typing.ClassVar[int] = ...
        pageSizeCompat: typing.ClassVar[int] = ...
        panelBackground: typing.ClassVar[int] = ...
        panelColorBackground: typing.ClassVar[int] = ...
        panelColorForeground: typing.ClassVar[int] = ...
        panelFullBackground: typing.ClassVar[int] = ...
        panelTextAppearance: typing.ClassVar[int] = ...
        parentActivityName: typing.ClassVar[int] = ...
        password: typing.ClassVar[int] = ...
        passwordsActivity: typing.ClassVar[int] = ...
        path: typing.ClassVar[int] = ...
        pathAdvancedPattern: typing.ClassVar[int] = ...
        pathData: typing.ClassVar[int] = ...
        pathPattern: typing.ClassVar[int] = ...
        pathPrefix: typing.ClassVar[int] = ...
        pathSuffix: typing.ClassVar[int] = ...
        patternPathData: typing.ClassVar[int] = ...
        permission: typing.ClassVar[int] = ...
        permissionFlags: typing.ClassVar[int] = ...
        permissionGroup: typing.ClassVar[int] = ...
        permissionGroupFlags: typing.ClassVar[int] = ...
        persistableMode: typing.ClassVar[int] = ...
        persistent: typing.ClassVar[int] = ...
        persistentDrawingCache: typing.ClassVar[int] = ...
        persistentWhenFeatureAvailable: typing.ClassVar[int] = ...
        phoneNumber: typing.ClassVar[int] = ...
        physicalKeyboardHintLanguageTag: typing.ClassVar[int] = ...
        physicalKeyboardHintLayoutType: typing.ClassVar[int] = ...
        pivotX: typing.ClassVar[int] = ...
        pivotY: typing.ClassVar[int] = ...
        pointerIcon: typing.ClassVar[int] = ...
        popupAnimationStyle: typing.ClassVar[int] = ...
        popupBackground: typing.ClassVar[int] = ...
        popupCharacters: typing.ClassVar[int] = ...
        popupElevation: typing.ClassVar[int] = ...
        popupEnterTransition: typing.ClassVar[int] = ...
        popupExitTransition: typing.ClassVar[int] = ...
        popupKeyboard: typing.ClassVar[int] = ...
        popupLayout: typing.ClassVar[int] = ...
        popupMenuStyle: typing.ClassVar[int] = ...
        popupTheme: typing.ClassVar[int] = ...
        popupWindowStyle: typing.ClassVar[int] = ...
        port: typing.ClassVar[int] = ...
        positiveButtonText: typing.ClassVar[int] = ...
        preferKeepClear: typing.ClassVar[int] = ...
        preferMinimalPostProcessing: typing.ClassVar[int] = ...
        preferenceCategoryStyle: typing.ClassVar[int] = ...
        preferenceFragmentStyle: typing.ClassVar[int] = ...
        preferenceInformationStyle: typing.ClassVar[int] = ...
        preferenceLayoutChild: typing.ClassVar[int] = ...
        preferenceScreenStyle: typing.ClassVar[int] = ...
        preferenceStyle: typing.ClassVar[int] = ...
        presentationTheme: typing.ClassVar[int] = ...
        preserveLegacyExternalStorage: typing.ClassVar[int] = ...
        previewImage: typing.ClassVar[int] = ...
        previewLayout: typing.ClassVar[int] = ...
        primaryContentAlpha: typing.ClassVar[int] = ...
        priority: typing.ClassVar[int] = ...
        privateImeOptions: typing.ClassVar[int] = ...
        process: typing.ClassVar[int] = ...
        progress: typing.ClassVar[int] = ...
        progressBackgroundTint: typing.ClassVar[int] = ...
        progressBackgroundTintMode: typing.ClassVar[int] = ...
        progressBarPadding: typing.ClassVar[int] = ...
        progressBarStyle: typing.ClassVar[int] = ...
        progressBarStyleHorizontal: typing.ClassVar[int] = ...
        progressBarStyleInverse: typing.ClassVar[int] = ...
        progressBarStyleLarge: typing.ClassVar[int] = ...
        progressBarStyleLargeInverse: typing.ClassVar[int] = ...
        progressBarStyleSmall: typing.ClassVar[int] = ...
        progressBarStyleSmallInverse: typing.ClassVar[int] = ...
        progressBarStyleSmallTitle: typing.ClassVar[int] = ...
        progressDrawable: typing.ClassVar[int] = ...
        progressTint: typing.ClassVar[int] = ...
        progressTintMode: typing.ClassVar[int] = ...
        prompt: typing.ClassVar[int] = ...
        propertyName: typing.ClassVar[int] = ...
        propertyXName: typing.ClassVar[int] = ...
        propertyYName: typing.ClassVar[int] = ...
        protectionLevel: typing.ClassVar[int] = ...
        publicKey: typing.ClassVar[int] = ...
        query: typing.ClassVar[int] = ...
        queryActionMsg: typing.ClassVar[int] = ...
        queryAdvancedPattern: typing.ClassVar[int] = ...
        queryAfterZeroResults: typing.ClassVar[int] = ...
        queryBackground: typing.ClassVar[int] = ...
        queryHint: typing.ClassVar[int] = ...
        queryPattern: typing.ClassVar[int] = ...
        queryPrefix: typing.ClassVar[int] = ...
        querySuffix: typing.ClassVar[int] = ...
        quickContactBadgeStyleSmallWindowLarge: typing.ClassVar[int] = ...
        quickContactBadgeStyleSmallWindowMedium: typing.ClassVar[int] = ...
        quickContactBadgeStyleSmallWindowSmall: typing.ClassVar[int] = ...
        quickContactBadgeStyleWindowLarge: typing.ClassVar[int] = ...
        quickContactBadgeStyleWindowMedium: typing.ClassVar[int] = ...
        quickContactBadgeStyleWindowSmall: typing.ClassVar[int] = ...
        radioButtonStyle: typing.ClassVar[int] = ...
        radius: typing.ClassVar[int] = ...
        rating: typing.ClassVar[int] = ...
        ratingBarStyle: typing.ClassVar[int] = ...
        ratingBarStyleIndicator: typing.ClassVar[int] = ...
        ratingBarStyleSmall: typing.ClassVar[int] = ...
        readPermission: typing.ClassVar[int] = ...
        recognitionService: typing.ClassVar[int] = ...
        recreateOnConfigChanges: typing.ClassVar[int] = ...
        recycleEnabled: typing.ClassVar[int] = ...
        relinquishTaskIdentity: typing.ClassVar[int] = ...
        reparent: typing.ClassVar[int] = ...
        reparentWithOverlay: typing.ClassVar[int] = ...
        repeatCount: typing.ClassVar[int] = ...
        repeatMode: typing.ClassVar[int] = ...
        reqFiveWayNav: typing.ClassVar[int] = ...
        reqHardKeyboard: typing.ClassVar[int] = ...
        reqKeyboardType: typing.ClassVar[int] = ...
        reqNavigation: typing.ClassVar[int] = ...
        reqTouchScreen: typing.ClassVar[int] = ...
        requestLegacyExternalStorage: typing.ClassVar[int] = ...
        requestRawExternalStorageAccess: typing.ClassVar[int] = ...
        requireContentUriPermissionFromCaller: typing.ClassVar[int] = ...
        requireDeviceScreenOn: typing.ClassVar[int] = ...
        requireDeviceUnlock: typing.ClassVar[int] = ...
        required: typing.ClassVar[int] = ...
        requiredAccountType: typing.ClassVar[int] = ...
        requiredDisplayCategory: typing.ClassVar[int] = ...
        requiredFeature: typing.ClassVar[int] = ...
        requiredForAllUsers: typing.ClassVar[int] = ...
        requiredNotFeature: typing.ClassVar[int] = ...
        requiredSplitTypes: typing.ClassVar[int] = ...
        requiresFadingEdge: typing.ClassVar[int] = ...
        requiresSmallestWidthDp: typing.ClassVar[int] = ...
        resetEnabledSettingsOnAppDataCleared: typing.ClassVar[int] = ...
        resizeClip: typing.ClassVar[int] = ...
        resizeMode: typing.ClassVar[int] = ...
        resizeable: typing.ClassVar[int] = ...
        resizeableActivity: typing.ClassVar[int] = ...
        resource: typing.ClassVar[int] = ...
        resourcesMap: typing.ClassVar[int] = ...
        restoreAnyVersion: typing.ClassVar[int] = ...
        restoreNeedsApplication: typing.ClassVar[int] = ...
        restrictedAccountType: typing.ClassVar[int] = ...
        restrictionType: typing.ClassVar[int] = ...
        resumeWhilePausing: typing.ClassVar[int] = ...
        reversible: typing.ClassVar[int] = ...
        revisionCode: typing.ClassVar[int] = ...
        right: typing.ClassVar[int] = ...
        ringtonePreferenceStyle: typing.ClassVar[int] = ...
        ringtoneType: typing.ClassVar[int] = ...
        rollbackDataPolicy: typing.ClassVar[int] = ...
        rotation: typing.ClassVar[int] = ...
        rotationAnimation: typing.ClassVar[int] = ...
        rotationX: typing.ClassVar[int] = ...
        rotationY: typing.ClassVar[int] = ...
        roundIcon: typing.ClassVar[int] = ...
        rowCount: typing.ClassVar[int] = ...
        rowDelay: typing.ClassVar[int] = ...
        rowEdgeFlags: typing.ClassVar[int] = ...
        rowHeight: typing.ClassVar[int] = ...
        rowOrderPreserved: typing.ClassVar[int] = ...
        saveEnabled: typing.ClassVar[int] = ...
        scaleGravity: typing.ClassVar[int] = ...
        scaleHeight: typing.ClassVar[int] = ...
        scaleType: typing.ClassVar[int] = ...
        scaleWidth: typing.ClassVar[int] = ...
        scaleX: typing.ClassVar[int] = ...
        scaleY: typing.ClassVar[int] = ...
        scheme: typing.ClassVar[int] = ...
        screenDensity: typing.ClassVar[int] = ...
        screenOrientation: typing.ClassVar[int] = ...
        screenReaderFocusable: typing.ClassVar[int] = ...
        screenSize: typing.ClassVar[int] = ...
        scrollHorizontally: typing.ClassVar[int] = ...
        scrollIndicators: typing.ClassVar[int] = ...
        scrollViewStyle: typing.ClassVar[int] = ...
        scrollX: typing.ClassVar[int] = ...
        scrollY: typing.ClassVar[int] = ...
        scrollbarAlwaysDrawHorizontalTrack: typing.ClassVar[int] = ...
        scrollbarAlwaysDrawVerticalTrack: typing.ClassVar[int] = ...
        scrollbarDefaultDelayBeforeFade: typing.ClassVar[int] = ...
        scrollbarFadeDuration: typing.ClassVar[int] = ...
        scrollbarSize: typing.ClassVar[int] = ...
        scrollbarStyle: typing.ClassVar[int] = ...
        scrollbarThumbHorizontal: typing.ClassVar[int] = ...
        scrollbarThumbVertical: typing.ClassVar[int] = ...
        scrollbarTrackHorizontal: typing.ClassVar[int] = ...
        scrollbarTrackVertical: typing.ClassVar[int] = ...
        scrollbars: typing.ClassVar[int] = ...
        scrollingCache: typing.ClassVar[int] = ...
        searchButtonText: typing.ClassVar[int] = ...
        searchHintIcon: typing.ClassVar[int] = ...
        searchIcon: typing.ClassVar[int] = ...
        searchMode: typing.ClassVar[int] = ...
        searchResultHighlightColor: typing.ClassVar[int] = ...
        searchSettingsDescription: typing.ClassVar[int] = ...
        searchSuggestAuthority: typing.ClassVar[int] = ...
        searchSuggestIntentAction: typing.ClassVar[int] = ...
        searchSuggestIntentData: typing.ClassVar[int] = ...
        searchSuggestPath: typing.ClassVar[int] = ...
        searchSuggestSelection: typing.ClassVar[int] = ...
        searchSuggestThreshold: typing.ClassVar[int] = ...
        searchViewStyle: typing.ClassVar[int] = ...
        secondaryContentAlpha: typing.ClassVar[int] = ...
        secondaryProgress: typing.ClassVar[int] = ...
        secondaryProgressTint: typing.ClassVar[int] = ...
        secondaryProgressTintMode: typing.ClassVar[int] = ...
        secureElementName: typing.ClassVar[int] = ...
        seekBarStyle: typing.ClassVar[int] = ...
        segmentedButtonStyle: typing.ClassVar[int] = ...
        selectAllOnFocus: typing.ClassVar[int] = ...
        selectable: typing.ClassVar[int] = ...
        selectableAsDefault: typing.ClassVar[int] = ...
        selectableItemBackground: typing.ClassVar[int] = ...
        selectableItemBackgroundBorderless: typing.ClassVar[int] = ...
        selectedDateVerticalBar: typing.ClassVar[int] = ...
        selectedWeekBackgroundColor: typing.ClassVar[int] = ...
        selectionDividerHeight: typing.ClassVar[int] = ...
        sessionService: typing.ClassVar[int] = ...
        settingsActivity: typing.ClassVar[int] = ...
        settingsSliceUri: typing.ClassVar[int] = ...
        settingsSubtitle: typing.ClassVar[int] = ...
        setupActivity: typing.ClassVar[int] = ...
        shadowColor: typing.ClassVar[int] = ...
        shadowDx: typing.ClassVar[int] = ...
        shadowDy: typing.ClassVar[int] = ...
        shadowRadius: typing.ClassVar[int] = ...
        shape: typing.ClassVar[int] = ...
        shareInterpolator: typing.ClassVar[int] = ...
        sharedUserId: typing.ClassVar[int] = ...
        sharedUserLabel: typing.ClassVar[int] = ...
        sharedUserMaxSdkVersion: typing.ClassVar[int] = ...
        shell: typing.ClassVar[int] = ...
        shiftDrawingOffsetForStartOverhang: typing.ClassVar[int] = ...
        shortcutDisabledMessage: typing.ClassVar[int] = ...
        shortcutId: typing.ClassVar[int] = ...
        shortcutLongLabel: typing.ClassVar[int] = ...
        shortcutShortLabel: typing.ClassVar[int] = ...
        shouldDefaultToObserveMode: typing.ClassVar[int] = ...
        shouldDisableView: typing.ClassVar[int] = ...
        shouldUseDefaultUnfoldTransition: typing.ClassVar[int] = ...
        showAsAction: typing.ClassVar[int] = ...
        showBackdrop: typing.ClassVar[int] = ...
        showClockAndComplications: typing.ClassVar[int] = ...
        showDefault: typing.ClassVar[int] = ...
        showDividers: typing.ClassVar[int] = ...
        showForAllUsers: typing.ClassVar[int] = ...
        showInInputMethodPicker: typing.ClassVar[int] = ...
        showMetadataInPreview: typing.ClassVar[int] = ...
        showOnLockScreen: typing.ClassVar[int] = ...
        showSilent: typing.ClassVar[int] = ...
        showText: typing.ClassVar[int] = ...
        showWeekNumber: typing.ClassVar[int] = ...
        showWhenLocked: typing.ClassVar[int] = ...
        shownWeekCount: typing.ClassVar[int] = ...
        shrinkColumns: typing.ClassVar[int] = ...
        singleLine: typing.ClassVar[int] = ...
        singleLineTitle: typing.ClassVar[int] = ...
        singleUser: typing.ClassVar[int] = ...
        slideEdge: typing.ClassVar[int] = ...
        smallIcon: typing.ClassVar[int] = ...
        smallScreens: typing.ClassVar[int] = ...
        smoothScrollbar: typing.ClassVar[int] = ...
        soundEffectsEnabled: typing.ClassVar[int] = ...
        spacing: typing.ClassVar[int] = ...
        spinnerDropDownItemStyle: typing.ClassVar[int] = ...
        spinnerItemStyle: typing.ClassVar[int] = ...
        spinnerMode: typing.ClassVar[int] = ...
        spinnerStyle: typing.ClassVar[int] = ...
        spinnersShown: typing.ClassVar[int] = ...
        splashScreenTheme: typing.ClassVar[int] = ...
        splitMotionEvents: typing.ClassVar[int] = ...
        splitName: typing.ClassVar[int] = ...
        splitTrack: typing.ClassVar[int] = ...
        splitTypes: typing.ClassVar[int] = ...
        spotShadowAlpha: typing.ClassVar[int] = ...
        src: typing.ClassVar[int] = ...
        ssp: typing.ClassVar[int] = ...
        sspAdvancedPattern: typing.ClassVar[int] = ...
        sspPattern: typing.ClassVar[int] = ...
        sspPrefix: typing.ClassVar[int] = ...
        sspSuffix: typing.ClassVar[int] = ...
        stackFromBottom: typing.ClassVar[int] = ...
        stackViewStyle: typing.ClassVar[int] = ...
        starStyle: typing.ClassVar[int] = ...
        start: typing.ClassVar[int] = ...
        startColor: typing.ClassVar[int] = ...
        startDelay: typing.ClassVar[int] = ...
        startOffset: typing.ClassVar[int] = ...
        startX: typing.ClassVar[int] = ...
        startY: typing.ClassVar[int] = ...
        startYear: typing.ClassVar[int] = ...
        stateListAnimator: typing.ClassVar[int] = ...
        stateNotNeeded: typing.ClassVar[int] = ...
        state_above_anchor: typing.ClassVar[int] = ...
        state_accelerated: typing.ClassVar[int] = ...
        state_activated: typing.ClassVar[int] = ...
        state_active: typing.ClassVar[int] = ...
        state_checkable: typing.ClassVar[int] = ...
        state_checked: typing.ClassVar[int] = ...
        state_drag_can_accept: typing.ClassVar[int] = ...
        state_drag_hovered: typing.ClassVar[int] = ...
        state_empty: typing.ClassVar[int] = ...
        state_enabled: typing.ClassVar[int] = ...
        state_expanded: typing.ClassVar[int] = ...
        state_first: typing.ClassVar[int] = ...
        state_focused: typing.ClassVar[int] = ...
        state_hovered: typing.ClassVar[int] = ...
        state_last: typing.ClassVar[int] = ...
        state_long_pressable: typing.ClassVar[int] = ...
        state_middle: typing.ClassVar[int] = ...
        state_multiline: typing.ClassVar[int] = ...
        state_pressed: typing.ClassVar[int] = ...
        state_selected: typing.ClassVar[int] = ...
        state_single: typing.ClassVar[int] = ...
        state_window_focused: typing.ClassVar[int] = ...
        staticWallpaperPreview: typing.ClassVar[int] = ...
        statusBarColor: typing.ClassVar[int] = ...
        stepSize: typing.ClassVar[int] = ...
        stopWithTask: typing.ClassVar[int] = ...
        streamType: typing.ClassVar[int] = ...
        stretchColumns: typing.ClassVar[int] = ...
        stretchMode: typing.ClassVar[int] = ...
        strokeAlpha: typing.ClassVar[int] = ...
        strokeColor: typing.ClassVar[int] = ...
        strokeLineCap: typing.ClassVar[int] = ...
        strokeLineJoin: typing.ClassVar[int] = ...
        strokeMiterLimit: typing.ClassVar[int] = ...
        strokeWidth: typing.ClassVar[int] = ...
        stylusHandwritingSettingsActivity: typing.ClassVar[int] = ...
        subMenuArrow: typing.ClassVar[int] = ...
        submitBackground: typing.ClassVar[int] = ...
        subtitle: typing.ClassVar[int] = ...
        subtitleTextAppearance: typing.ClassVar[int] = ...
        subtitleTextColor: typing.ClassVar[int] = ...
        subtitleTextStyle: typing.ClassVar[int] = ...
        subtypeExtraValue: typing.ClassVar[int] = ...
        subtypeId: typing.ClassVar[int] = ...
        subtypeLocale: typing.ClassVar[int] = ...
        suggestActionMsg: typing.ClassVar[int] = ...
        suggestActionMsgColumn: typing.ClassVar[int] = ...
        suggestionRowLayout: typing.ClassVar[int] = ...
        summary: typing.ClassVar[int] = ...
        summaryColumn: typing.ClassVar[int] = ...
        summaryOff: typing.ClassVar[int] = ...
        summaryOn: typing.ClassVar[int] = ...
        supplementalDescription: typing.ClassVar[int] = ...
        supportedTypes: typing.ClassVar[int] = ...
        supportsAssist: typing.ClassVar[int] = ...
        supportsBatteryGameMode: typing.ClassVar[int] = ...
        supportsConnectionlessStylusHandwriting: typing.ClassVar[int] = ...
        supportsInlineSuggestions: typing.ClassVar[int] = ...
        supportsInlineSuggestionsWithTouchExploration: typing.ClassVar[int] = ...
        supportsLaunchVoiceAssistFromKeyguard: typing.ClassVar[int] = ...
        supportsLocalInteraction: typing.ClassVar[int] = ...
        supportsMultipleDisplays: typing.ClassVar[int] = ...
        supportsPerformanceGameMode: typing.ClassVar[int] = ...
        supportsPictureInPicture: typing.ClassVar[int] = ...
        supportsRtl: typing.ClassVar[int] = ...
        supportsStylusHandwriting: typing.ClassVar[int] = ...
        supportsSwitchingToNextInputMethod: typing.ClassVar[int] = ...
        supportsUploading: typing.ClassVar[int] = ...
        suppressesSpellChecker: typing.ClassVar[int] = ...
        switchMinWidth: typing.ClassVar[int] = ...
        switchPadding: typing.ClassVar[int] = ...
        switchPreferenceStyle: typing.ClassVar[int] = ...
        switchStyle: typing.ClassVar[int] = ...
        switchTextAppearance: typing.ClassVar[int] = ...
        switchTextOff: typing.ClassVar[int] = ...
        switchTextOn: typing.ClassVar[int] = ...
        syncable: typing.ClassVar[int] = ...
        systemUserOnly: typing.ClassVar[int] = ...
        tabStripEnabled: typing.ClassVar[int] = ...
        tabStripLeft: typing.ClassVar[int] = ...
        tabStripRight: typing.ClassVar[int] = ...
        tabWidgetStyle: typing.ClassVar[int] = ...
        tag: typing.ClassVar[int] = ...
        targetActivity: typing.ClassVar[int] = ...
        targetCellHeight: typing.ClassVar[int] = ...
        targetCellWidth: typing.ClassVar[int] = ...
        targetClass: typing.ClassVar[int] = ...
        targetDescriptions: typing.ClassVar[int] = ...
        targetId: typing.ClassVar[int] = ...
        targetName: typing.ClassVar[int] = ...
        targetPackage: typing.ClassVar[int] = ...
        targetProcesses: typing.ClassVar[int] = ...
        targetSandboxVersion: typing.ClassVar[int] = ...
        targetSdkVersion: typing.ClassVar[int] = ...
        taskAffinity: typing.ClassVar[int] = ...
        taskCloseEnterAnimation: typing.ClassVar[int] = ...
        taskCloseExitAnimation: typing.ClassVar[int] = ...
        taskOpenEnterAnimation: typing.ClassVar[int] = ...
        taskOpenExitAnimation: typing.ClassVar[int] = ...
        taskToBackEnterAnimation: typing.ClassVar[int] = ...
        taskToBackExitAnimation: typing.ClassVar[int] = ...
        taskToFrontEnterAnimation: typing.ClassVar[int] = ...
        taskToFrontExitAnimation: typing.ClassVar[int] = ...
        tension: typing.ClassVar[int] = ...
        testOnly: typing.ClassVar[int] = ...
        text: typing.ClassVar[int] = ...
        textAlignment: typing.ClassVar[int] = ...
        textAllCaps: typing.ClassVar[int] = ...
        textAppearance: typing.ClassVar[int] = ...
        textAppearanceButton: typing.ClassVar[int] = ...
        textAppearanceInverse: typing.ClassVar[int] = ...
        textAppearanceLarge: typing.ClassVar[int] = ...
        textAppearanceLargeInverse: typing.ClassVar[int] = ...
        textAppearanceLargePopupMenu: typing.ClassVar[int] = ...
        textAppearanceListItem: typing.ClassVar[int] = ...
        textAppearanceListItemSecondary: typing.ClassVar[int] = ...
        textAppearanceListItemSmall: typing.ClassVar[int] = ...
        textAppearanceMedium: typing.ClassVar[int] = ...
        textAppearanceMediumInverse: typing.ClassVar[int] = ...
        textAppearancePopupMenuHeader: typing.ClassVar[int] = ...
        textAppearanceSearchResultSubtitle: typing.ClassVar[int] = ...
        textAppearanceSearchResultTitle: typing.ClassVar[int] = ...
        textAppearanceSmall: typing.ClassVar[int] = ...
        textAppearanceSmallInverse: typing.ClassVar[int] = ...
        textAppearanceSmallPopupMenu: typing.ClassVar[int] = ...
        textCheckMark: typing.ClassVar[int] = ...
        textCheckMarkInverse: typing.ClassVar[int] = ...
        textColor: typing.ClassVar[int] = ...
        textColorAlertDialogListItem: typing.ClassVar[int] = ...
        textColorHighlight: typing.ClassVar[int] = ...
        textColorHighlightInverse: typing.ClassVar[int] = ...
        textColorHint: typing.ClassVar[int] = ...
        textColorHintInverse: typing.ClassVar[int] = ...
        textColorLink: typing.ClassVar[int] = ...
        textColorLinkInverse: typing.ClassVar[int] = ...
        textColorPrimary: typing.ClassVar[int] = ...
        textColorPrimaryDisableOnly: typing.ClassVar[int] = ...
        textColorPrimaryInverse: typing.ClassVar[int] = ...
        textColorPrimaryInverseDisableOnly: typing.ClassVar[int] = ...
        textColorPrimaryInverseNoDisable: typing.ClassVar[int] = ...
        textColorPrimaryNoDisable: typing.ClassVar[int] = ...
        textColorSecondary: typing.ClassVar[int] = ...
        textColorSecondaryInverse: typing.ClassVar[int] = ...
        textColorSecondaryInverseNoDisable: typing.ClassVar[int] = ...
        textColorSecondaryNoDisable: typing.ClassVar[int] = ...
        textColorTertiary: typing.ClassVar[int] = ...
        textColorTertiaryInverse: typing.ClassVar[int] = ...
        textCursorDrawable: typing.ClassVar[int] = ...
        textDirection: typing.ClassVar[int] = ...
        textEditNoPasteWindowLayout: typing.ClassVar[int] = ...
        textEditPasteWindowLayout: typing.ClassVar[int] = ...
        textEditSideNoPasteWindowLayout: typing.ClassVar[int] = ...
        textEditSidePasteWindowLayout: typing.ClassVar[int] = ...
        textEditSuggestionItemLayout: typing.ClassVar[int] = ...
        textFilterEnabled: typing.ClassVar[int] = ...
        textFontWeight: typing.ClassVar[int] = ...
        textIsSelectable: typing.ClassVar[int] = ...
        textLocale: typing.ClassVar[int] = ...
        textOff: typing.ClassVar[int] = ...
        textOn: typing.ClassVar[int] = ...
        textScaleX: typing.ClassVar[int] = ...
        textSelectHandle: typing.ClassVar[int] = ...
        textSelectHandleLeft: typing.ClassVar[int] = ...
        textSelectHandleRight: typing.ClassVar[int] = ...
        textSelectHandleWindowStyle: typing.ClassVar[int] = ...
        textSize: typing.ClassVar[int] = ...
        textStyle: typing.ClassVar[int] = ...
        textSuggestionsWindowStyle: typing.ClassVar[int] = ...
        textViewStyle: typing.ClassVar[int] = ...
        theme: typing.ClassVar[int] = ...
        thickness: typing.ClassVar[int] = ...
        thicknessRatio: typing.ClassVar[int] = ...
        thumb: typing.ClassVar[int] = ...
        thumbOffset: typing.ClassVar[int] = ...
        thumbPosition: typing.ClassVar[int] = ...
        thumbTextPadding: typing.ClassVar[int] = ...
        thumbTint: typing.ClassVar[int] = ...
        thumbTintMode: typing.ClassVar[int] = ...
        thumbnail: typing.ClassVar[int] = ...
        tickMark: typing.ClassVar[int] = ...
        tickMarkTint: typing.ClassVar[int] = ...
        tickMarkTintMode: typing.ClassVar[int] = ...
        tileMode: typing.ClassVar[int] = ...
        tileModeX: typing.ClassVar[int] = ...
        tileModeY: typing.ClassVar[int] = ...
        tileService: typing.ClassVar[int] = ...
        timePickerDialogTheme: typing.ClassVar[int] = ...
        timePickerMode: typing.ClassVar[int] = ...
        timePickerStyle: typing.ClassVar[int] = ...
        timeZone: typing.ClassVar[int] = ...
        tint: typing.ClassVar[int] = ...
        tintMode: typing.ClassVar[int] = ...
        title: typing.ClassVar[int] = ...
        titleCondensed: typing.ClassVar[int] = ...
        titleMargin: typing.ClassVar[int] = ...
        titleMarginBottom: typing.ClassVar[int] = ...
        titleMarginEnd: typing.ClassVar[int] = ...
        titleMarginStart: typing.ClassVar[int] = ...
        titleMarginTop: typing.ClassVar[int] = ...
        titleTextAppearance: typing.ClassVar[int] = ...
        titleTextColor: typing.ClassVar[int] = ...
        titleTextStyle: typing.ClassVar[int] = ...
        toAlpha: typing.ClassVar[int] = ...
        toDegrees: typing.ClassVar[int] = ...
        toExtendBottom: typing.ClassVar[int] = ...
        toExtendLeft: typing.ClassVar[int] = ...
        toExtendRight: typing.ClassVar[int] = ...
        toExtendTop: typing.ClassVar[int] = ...
        toId: typing.ClassVar[int] = ...
        toScene: typing.ClassVar[int] = ...
        toXDelta: typing.ClassVar[int] = ...
        toXScale: typing.ClassVar[int] = ...
        toYDelta: typing.ClassVar[int] = ...
        toYScale: typing.ClassVar[int] = ...
        toolbarStyle: typing.ClassVar[int] = ...
        tooltipText: typing.ClassVar[int] = ...
        top: typing.ClassVar[int] = ...
        topBright: typing.ClassVar[int] = ...
        topDark: typing.ClassVar[int] = ...
        topLeftRadius: typing.ClassVar[int] = ...
        topOffset: typing.ClassVar[int] = ...
        topRightRadius: typing.ClassVar[int] = ...
        touchscreenBlocksFocus: typing.ClassVar[int] = ...
        track: typing.ClassVar[int] = ...
        trackTint: typing.ClassVar[int] = ...
        trackTintMode: typing.ClassVar[int] = ...
        transcriptMode: typing.ClassVar[int] = ...
        transformPivotX: typing.ClassVar[int] = ...
        transformPivotY: typing.ClassVar[int] = ...
        transition: typing.ClassVar[int] = ...
        transitionGroup: typing.ClassVar[int] = ...
        transitionName: typing.ClassVar[int] = ...
        transitionOrdering: typing.ClassVar[int] = ...
        transitionVisibilityMode: typing.ClassVar[int] = ...
        translateX: typing.ClassVar[int] = ...
        translateY: typing.ClassVar[int] = ...
        translationX: typing.ClassVar[int] = ...
        translationY: typing.ClassVar[int] = ...
        translationZ: typing.ClassVar[int] = ...
        trimPathEnd: typing.ClassVar[int] = ...
        trimPathOffset: typing.ClassVar[int] = ...
        trimPathStart: typing.ClassVar[int] = ...
        ttcIndex: typing.ClassVar[int] = ...
        tunerCount: typing.ClassVar[int] = ...
        turnScreenOn: typing.ClassVar[int] = ...
        type: typing.ClassVar[int] = ...
        typeface: typing.ClassVar[int] = ...
        uiOptions: typing.ClassVar[int] = ...
        uncertainGestureColor: typing.ClassVar[int] = ...
        unfocusedMonthDateColor: typing.ClassVar[int] = ...
        unselectedAlpha: typing.ClassVar[int] = ...
        updatePeriodMillis: typing.ClassVar[int] = ...
        use32bitAbi: typing.ClassVar[int] = ...
        useAppZygote: typing.ClassVar[int] = ...
        useBoundsForWidth: typing.ClassVar[int] = ...
        useDefaultMargins: typing.ClassVar[int] = ...
        useEmbeddedDex: typing.ClassVar[int] = ...
        useIntrinsicSizeAsMinimum: typing.ClassVar[int] = ...
        useLevel: typing.ClassVar[int] = ...
        useLocalePreferredLineHeightForMinimum: typing.ClassVar[int] = ...
        userVisible: typing.ClassVar[int] = ...
        usesCleartextTraffic: typing.ClassVar[int] = ...
        usesPermissionFlags: typing.ClassVar[int] = ...
        value: typing.ClassVar[int] = ...
        valueFrom: typing.ClassVar[int] = ...
        valueTo: typing.ClassVar[int] = ...
        valueType: typing.ClassVar[int] = ...
        variablePadding: typing.ClassVar[int] = ...
        vendor: typing.ClassVar[int] = ...
        version: typing.ClassVar[int] = ...
        versionCode: typing.ClassVar[int] = ...
        versionCodeMajor: typing.ClassVar[int] = ...
        versionMajor: typing.ClassVar[int] = ...
        versionName: typing.ClassVar[int] = ...
        verticalCorrection: typing.ClassVar[int] = ...
        verticalDivider: typing.ClassVar[int] = ...
        verticalGap: typing.ClassVar[int] = ...
        verticalScrollbarPosition: typing.ClassVar[int] = ...
        verticalSpacing: typing.ClassVar[int] = ...
        viewportHeight: typing.ClassVar[int] = ...
        viewportWidth: typing.ClassVar[int] = ...
        visibility: typing.ClassVar[int] = ...
        visible: typing.ClassVar[int] = ...
        visibleToInstantApps: typing.ClassVar[int] = ...
        vmSafeMode: typing.ClassVar[int] = ...
        voiceIcon: typing.ClassVar[int] = ...
        voiceLanguage: typing.ClassVar[int] = ...
        voiceLanguageModel: typing.ClassVar[int] = ...
        voiceMaxResults: typing.ClassVar[int] = ...
        voicePromptText: typing.ClassVar[int] = ...
        voiceSearchMode: typing.ClassVar[int] = ...
        wallpaperCloseEnterAnimation: typing.ClassVar[int] = ...
        wallpaperCloseExitAnimation: typing.ClassVar[int] = ...
        wallpaperIntraCloseEnterAnimation: typing.ClassVar[int] = ...
        wallpaperIntraCloseExitAnimation: typing.ClassVar[int] = ...
        wallpaperIntraOpenEnterAnimation: typing.ClassVar[int] = ...
        wallpaperIntraOpenExitAnimation: typing.ClassVar[int] = ...
        wallpaperOpenEnterAnimation: typing.ClassVar[int] = ...
        wallpaperOpenExitAnimation: typing.ClassVar[int] = ...
        wantsRoleHolderPriority: typing.ClassVar[int] = ...
        webTextViewStyle: typing.ClassVar[int] = ...
        webViewStyle: typing.ClassVar[int] = ...
        weekDayTextAppearance: typing.ClassVar[int] = ...
        weekNumberColor: typing.ClassVar[int] = ...
        weekSeparatorLineColor: typing.ClassVar[int] = ...
        weightSum: typing.ClassVar[int] = ...
        widgetCategory: typing.ClassVar[int] = ...
        widgetFeatures: typing.ClassVar[int] = ...
        widgetLayout: typing.ClassVar[int] = ...
        width: typing.ClassVar[int] = ...
        windowActionBar: typing.ClassVar[int] = ...
        windowActionBarOverlay: typing.ClassVar[int] = ...
        windowActionModeOverlay: typing.ClassVar[int] = ...
        windowActivityTransitions: typing.ClassVar[int] = ...
        windowAllowEnterTransitionOverlap: typing.ClassVar[int] = ...
        windowAllowReturnTransitionOverlap: typing.ClassVar[int] = ...
        windowAnimationStyle: typing.ClassVar[int] = ...
        windowBackground: typing.ClassVar[int] = ...
        windowBackgroundBlurRadius: typing.ClassVar[int] = ...
        windowBackgroundFallback: typing.ClassVar[int] = ...
        windowBlurBehindEnabled: typing.ClassVar[int] = ...
        windowBlurBehindRadius: typing.ClassVar[int] = ...
        windowClipToOutline: typing.ClassVar[int] = ...
        windowCloseOnTouchOutside: typing.ClassVar[int] = ...
        windowContentOverlay: typing.ClassVar[int] = ...
        windowContentTransitionManager: typing.ClassVar[int] = ...
        windowContentTransitions: typing.ClassVar[int] = ...
        windowDisablePreview: typing.ClassVar[int] = ...
        windowDrawsSystemBarBackgrounds: typing.ClassVar[int] = ...
        windowElevation: typing.ClassVar[int] = ...
        windowEnableSplitTouch: typing.ClassVar[int] = ...
        windowEnterAnimation: typing.ClassVar[int] = ...
        windowEnterTransition: typing.ClassVar[int] = ...
        windowExitAnimation: typing.ClassVar[int] = ...
        windowExitTransition: typing.ClassVar[int] = ...
        windowFrame: typing.ClassVar[int] = ...
        windowFullscreen: typing.ClassVar[int] = ...
        windowHideAnimation: typing.ClassVar[int] = ...
        windowIsFloating: typing.ClassVar[int] = ...
        windowIsFrameRatePowerSavingsBalanced: typing.ClassVar[int] = ...
        windowIsTranslucent: typing.ClassVar[int] = ...
        windowLayoutAffinity: typing.ClassVar[int] = ...
        windowLayoutInDisplayCutoutMode: typing.ClassVar[int] = ...
        windowLightNavigationBar: typing.ClassVar[int] = ...
        windowLightStatusBar: typing.ClassVar[int] = ...
        windowMinWidthMajor: typing.ClassVar[int] = ...
        windowMinWidthMinor: typing.ClassVar[int] = ...
        windowNoDisplay: typing.ClassVar[int] = ...
        windowNoMoveAnimation: typing.ClassVar[int] = ...
        windowNoTitle: typing.ClassVar[int] = ...
        windowOptOutEdgeToEdgeEnforcement: typing.ClassVar[int] = ...
        windowOverscan: typing.ClassVar[int] = ...
        windowReenterTransition: typing.ClassVar[int] = ...
        windowReturnTransition: typing.ClassVar[int] = ...
        windowSharedElementEnterTransition: typing.ClassVar[int] = ...
        windowSharedElementExitTransition: typing.ClassVar[int] = ...
        windowSharedElementReenterTransition: typing.ClassVar[int] = ...
        windowSharedElementReturnTransition: typing.ClassVar[int] = ...
        windowSharedElementsUseOverlay: typing.ClassVar[int] = ...
        windowShowAnimation: typing.ClassVar[int] = ...
        windowShowWallpaper: typing.ClassVar[int] = ...
        windowSoftInputMode: typing.ClassVar[int] = ...
        windowSplashScreenAnimatedIcon: typing.ClassVar[int] = ...
        windowSplashScreenAnimationDuration: typing.ClassVar[int] = ...
        windowSplashScreenBackground: typing.ClassVar[int] = ...
        windowSplashScreenBehavior: typing.ClassVar[int] = ...
        windowSplashScreenBrandingImage: typing.ClassVar[int] = ...
        windowSplashScreenIconBackgroundColor: typing.ClassVar[int] = ...
        windowSplashscreenContent: typing.ClassVar[int] = ...
        windowSwipeToDismiss: typing.ClassVar[int] = ...
        windowTitleBackgroundStyle: typing.ClassVar[int] = ...
        windowTitleSize: typing.ClassVar[int] = ...
        windowTitleStyle: typing.ClassVar[int] = ...
        windowTransitionBackgroundFadeDuration: typing.ClassVar[int] = ...
        windowTranslucentNavigation: typing.ClassVar[int] = ...
        windowTranslucentStatus: typing.ClassVar[int] = ...
        writePermission: typing.ClassVar[int] = ...
        x: typing.ClassVar[int] = ...
        xlargeScreens: typing.ClassVar[int] = ...
        y: typing.ClassVar[int] = ...
        yearListItemTextAppearance: typing.ClassVar[int] = ...
        yearListSelectorColor: typing.ClassVar[int] = ...
        yesNoPreferenceStyle: typing.ClassVar[int] = ...
        zAdjustment: typing.ClassVar[int] = ...
        zygotePreloadName: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class array(java.lang.Object):
        emailAddressTypes: typing.ClassVar[int] = ...
        imProtocols: typing.ClassVar[int] = ...
        organizationTypes: typing.ClassVar[int] = ...
        phoneTypes: typing.ClassVar[int] = ...
        postalAddressTypes: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class animator(java.lang.Object):
        fade_in: typing.ClassVar[int] = ...
        fade_out: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class anim(java.lang.Object):
        accelerate_decelerate_interpolator: typing.ClassVar[int] = ...
        accelerate_interpolator: typing.ClassVar[int] = ...
        anticipate_interpolator: typing.ClassVar[int] = ...
        anticipate_overshoot_interpolator: typing.ClassVar[int] = ...
        bounce_interpolator: typing.ClassVar[int] = ...
        cycle_interpolator: typing.ClassVar[int] = ...
        decelerate_interpolator: typing.ClassVar[int] = ...
        fade_in: typing.ClassVar[int] = ...
        fade_out: typing.ClassVar[int] = ...
        linear_interpolator: typing.ClassVar[int] = ...
        overshoot_interpolator: typing.ClassVar[int] = ...
        slide_in_left: typing.ClassVar[int] = ...
        slide_out_right: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
